Python: module mx2.enums

mx2.enums | index /Users/vpaeder/Projects/pymx2/mx2/enums.py

`Enums for MX2 driver.`

Modules
`` |  |
enum |  |  |

Classes
`` |  | enum.Enum(builtins.object) Register FineTuningFunctions IntelligentTerminalFunctions MainProfileParameters ModbusRegisters MonitoringFunctions MotorConstantsFunctions OtherParameters SecondMotorFunctions StandardFunctions enum.IntEnum(builtins.int, enum.Enum) Coil ExceptionCode FaultMonitorData FunctionCode InverterStatus TripFactor
class Coil(enum.IntEnum)
`` | `Coil(value, names=None, *, module=None, qualname=None, type=None, start=1) Coil addresses (datasheet section B-4, p. 316).`
| Method resolution order: Coil enum.IntEnum builtins.int enum.Enum builtins.object Data and other attributes defined here: Alarm = <Coil.Alarm: 0x18> AnalogCurrentIODisconnected = <Coil.AnalogCurrentIODisconnected: 0x2f> AnalogVoltageIODisconnected = <Coil.AnalogVoltageIODisconnected: 0x2e> BrakeError = <Coil.BrakeError: 0x27> BrakeRelease = <Coil.BrakeRelease: 0x26> CRCError = <Coil.CRCError: 0x4a> CapacitorLifeWarning = <Coil.CapacitorLifeWarning: 0x3a> CommunicationTrainDisconnection = <Coil.CommunicationTrainDisconnection: 0x33> ConstantSpeedReached = <Coil.ConstantSpeedReached: 0x14> CoolingFanSpeedDrop = <Coil.CoolingFanSpeedDrop: 0x3b> DataWritingInProgress = <Coil.DataWritingInProgress: 0x49> ExternalTrip = <Coil.ExternalTrip: 0x03> ForwardRotation = <Coil.ForwardRotation: 0x46> FramingError = <Coil.FramingError: 0x4c> FrequencyCommandSource = <Coil.FrequencyCommandSource: 0x54> GateSuppressMonitor = <Coil.GateSuppressMonitor: 0x58> GeneralOutput1 = <Coil.GeneralOutput1: 0x3f> GeneralOutput2 = <Coil.GeneralOutput2: 0x40> GeneralOutput3 = <Coil.GeneralOutput3: 0x41> HeatSinkOverheatWarning = <Coil.HeatSinkOverheatWarning: 0x3d> IntelligentInput1 = <Coil.IntelligentInput1: 0x07> IntelligentInput2 = <Coil.IntelligentInput2: 0x08> IntelligentInput3 = <Coil.IntelligentInput3: 0x09> IntelligentInput4 = <Coil.IntelligentInput4: 0x0a> IntelligentInput5 = <Coil.IntelligentInput5: 0x0b> IntelligentInput6 = <Coil.IntelligentInput6: 0x0c> IntelligentInput7 = <Coil.IntelligentInput7: 0x0d> InverterReady = <Coil.InverterReady: 0x11> InverterReadyOutput = <Coil.InverterReadyOutput: 0x45> LogicalOperationResult1 = <Coil.LogicalOperationResult1: 0x34> LogicalOperationResult2 = <Coil.LogicalOperationResult2: 0x35> LogicalOperationResult3 = <Coil.LogicalOperationResult3: 0x36> LowCurrentIndicator = <Coil.LowCurrentIndicator: 0x3e> MajorFailure = <Coil.MajorFailure: 0x48> OperationCommand = <Coil.OperationCommand: 0x01> OperationStatus = <Coil.OperationStatus: 0x0f> OperationTimeOver = <Coil.OperationTimeOver: 0x1e> OptionDisconnection = <Coil.OptionDisconnection: 0x53> OutputDeviation = <Coil.OutputDeviation: 0x17> OverTorque = <Coil.OverTorque: 0x1a> Overload = <Coil.Overload: 0x16> Overload2 = <Coil.Overload2: 0x2d> Overrun = <Coil.Overrun: 0x4b> PIDFeedbackComparison = <Coil.PIDFeedbackComparison: 0x32> ParityError = <Coil.ParityError: 0x4d> PlugInTimeOver = <Coil.PlugInTimeOver: 0x1f> PositioningCompleted = <Coil.PositioningCompleted: 0x2a> ReverseRotation = <Coil.ReverseRotation: 0x47> RotationDirectionCommand = <Coil.RotationDirectionCommand: 0x02> RotationDirectionStatus = <Coil.RotationDirectionStatus: 0x10> RunCommandSource = <Coil.RunCommandSource: 0x55> Running = <Coil.Running: 0x13> SecondMotorSelected = <Coil.SecondMotorSelected: 0x56> SetFrequencyOverreached = <Coil.SetFrequencyOverreached: 0x15> SetFrequencyOverreached2 = <Coil.SetFrequencyOverreached2: 0x2b> SetFrequencyReached = <Coil.SetFrequencyReached: 0x19> SetFrequencyReached2 = <Coil.SetFrequencyReached2: 0x2c> SpeedDeviationMaximum = <Coil.SpeedDeviationMaximum: 0x29> StartingContactSignal = <Coil.StartingContactSignal: 0x3c> SumCheckError = <Coil.SumCheckError: 0x4e> ThermalAlarm = <Coil.ThermalAlarm: 0x20> TorqueLimited = <Coil.TorqueLimited: 0x1d> TripReset = <Coil.TripReset: 0x04> UnderVoltage = <Coil.UnderVoltage: 0x1c> WindowComparatorCurrent = <Coil.WindowComparatorCurrent: 0x51> WindowComparatorVoltage = <Coil.WindowComparatorVoltage: 0x50> ZeroHzDetection = <Coil.ZeroHzDetection: 0x28> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
class ExceptionCode(enum.IntEnum)
`` | `ExceptionCode(value, names=None, *, module=None, qualname=None, type=None, start=1) Exception codes replied by inverter if an exception occurs (datasheet section B-3, p. 300).`
| Method resolution order: ExceptionCode enum.IntEnum builtins.int enum.Enum builtins.object Data and other attributes defined here: FunctionNotAvailable = <ExceptionCode.FunctionNotAvailable: 34> FunctionNotFound = <ExceptionCode.FunctionNotFound: 2> FunctionNotSupported = <ExceptionCode.FunctionNotSupported: 1> InvalidDataFormat = <ExceptionCode.InvalidDataFormat: 3> OutOfBounds = <ExceptionCode.OutOfBounds: 33> ReadOnlyTarget = <ExceptionCode.ReadOnlyTarget: 35> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
class FaultMonitorData(enum.IntEnum)
`` | `FaultMonitorData(value, names=None, *, module=None, qualname=None, type=None, start=1) Register offset for fault monitor data access. This is meant to be used with fault monitor 1 to 6 commands (D081 - D086) as listed in datasheet section B-4 pp. 319-320. Use MonitoringFunctions.D08y + FaultMonitorData.xxx to access xxx of fault monitor y.`
| Method resolution order: FaultMonitorData enum.IntEnum builtins.int enum.Enum builtins.object Data and other attributes defined here: Current = <FaultMonitorData.Current: 4> Factor = <FaultMonitorData.Factor: 0> Frequency = <FaultMonitorData.Frequency: 2> InverterStatus = <FaultMonitorData.InverterStatus: 1> PowerOnTime = <FaultMonitorData.PowerOnTime: 8> RunningTime = <FaultMonitorData.RunningTime: 6> Voltage = <FaultMonitorData.Voltage: 5> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
class FineTuningFunctions(Register)
`` | `FineTuningFunctions(value, names=None, *, module=None, qualname=None, type=None, start=1) Fine tuning function group. See datasheet sections 3-6 (pp. 121-153) and B-4 (pp. 328-331).`
| Method resolution order: FineTuningFunctions Register enum.Enum builtins.object Data and other attributes defined here: ActiveFrequencyMatchingRestartLevel = <FineTuningFunctions.ActiveFrequencyMatchingRestartLevel: (0x131d, 1)> ActiveFrequencyMatchingRestartParameter = <FineTuningFunctions.ActiveFrequencyMatchingRestartParameter: (0x131e, 1)> AllowableMomentaryPowerInterruptionTime = <FineTuningFunctions.AllowableMomentaryPowerInterruptionTime: (0x1302, 1)> AmbientTemperature = <FineTuningFunctions.AmbientTemperature: (0x134e, 1)> AnalogCurrentLevelAtDisconnection = <FineTuningFunctions.AnalogCurrentLevelAtDisconnection: (0x134a, 1)> AnalogVoltageLevelAtDisconnection = <FineTuningFunctions.AnalogVoltageLevelAtDisconnection: (0x1349, 1)> AutoReturnInitialDisplay = <FineTuningFunctions.AutoReturnInitialDisplay: (0x13a7, 1)> AutomaticCarrierFrequencyReduction = <FineTuningFunctions.AutomaticCarrierFrequencyReduction: (0x135c, 1)> BRDResistor = <FineTuningFunctions.BRDResistor: (0x1364, 1)> BrakeControlSelection = <FineTuningFunctions.BrakeControlSelection: (0x137b, 1)> BrakeInputFrequency = <FineTuningFunctions.BrakeInputFrequency: (0x1382, 1)> BrakeReleaseCurrent = <FineTuningFunctions.BrakeReleaseCurrent: (0x1381, 1)> BrakeReleaseFrequency = <FineTuningFunctions.BrakeReleaseFrequency: (0x1380, 1)> BrakeWaitTimeForAcceleration = <FineTuningFunctions.BrakeWaitTimeForAcceleration: (0x137d, 1)> BrakeWaitTimeForConfirmation = <FineTuningFunctions.BrakeWaitTimeForConfirmation: (0x137f, 1)> BrakeWaitTimeForRelease = <FineTuningFunctions.BrakeWaitTimeForRelease: (0x137c, 1)> BrakeWaitTimeForStopping = <FineTuningFunctions.BrakeWaitTimeForStopping: (0x137e, 1)> CarrierFrequency = <FineTuningFunctions.CarrierFrequency: (0x1356, 1)> ClearElapsedTimeOfCoolingFan = <FineTuningFunctions.ClearElapsedTimeOfCoolingFan: (0x1360, 1)> CoolingFanControl = <FineTuningFunctions.CoolingFanControl: (0x135f, 1)> DataReadWriteSelection = <FineTuningFunctions.DataReadWriteSelection: (0x13a9, 1)> DecelerationStartingWidthOfNonStopFunction = <FineTuningFunctions.DecelerationStartingWidthOfNonStopFunction: (0x1339, 1)> DecelerationTimeOfNonStopFunction = <FineTuningFunctions.DecelerationTimeOfNonStopFunction: (0x1337, 2)> DisplayExternalOperatorConnected = <FineTuningFunctions.DisplayExternalOperatorConnected: (0x139a, 1)> DisplaySelection = <FineTuningFunctions.DisplaySelection: (0x1327, 1)> DualRateSelection = <FineTuningFunctions.DualRateSelection: (0x1333, 1)> ElectronicThermalCharacteristicsSelection = <FineTuningFunctions.ElectronicThermalCharacteristicsSelection: (0x130e, 1)> ElectronicThermalCurrent1 = <FineTuningFunctions.ElectronicThermalCurrent1: (0x1311, 1)> ElectronicThermalCurrent2 = <FineTuningFunctions.ElectronicThermalCurrent2: (0x1313, 1)> ElectronicThermalCurrent3 = <FineTuningFunctions.ElectronicThermalCurrent3: (0x1315, 1)> ElectronicThermalFrequency1 = <FineTuningFunctions.ElectronicThermalFrequency1: (0x1310, 1)> ElectronicThermalFrequency2 = <FineTuningFunctions.ElectronicThermalFrequency2: (0x1312, 1)> ElectronicThermalFrequency3 = <FineTuningFunctions.ElectronicThermalFrequency3: (0x1314, 1)> ElectronicThermalLevel = <FineTuningFunctions.ElectronicThermalLevel: (0x130d, 1)> ExternalOperatorDisconnectionAction = <FineTuningFunctions.ExternalOperatorDisconnectionAction: (0x13a8, 1)> FirstDualMonitorParameter = <FineTuningFunctions.FirstDualMonitorParameter: (0x13a3, 1)> FreeRunStopSelection = <FineTuningFunctions.FreeRunStopSelection: (0x135b, 1)> FreeVfFrequency1 = <FineTuningFunctions.FreeVfFrequency1: (0x1367, 1)> FreeVfFrequency2 = <FineTuningFunctions.FreeVfFrequency2: (0x1369, 1)> FreeVfFrequency3 = <FineTuningFunctions.FreeVfFrequency3: (0x136b, 1)> FreeVfFrequency4 = <FineTuningFunctions.FreeVfFrequency4: (0x136d, 1)> FreeVfFrequency5 = <FineTuningFunctions.FreeVfFrequency5: (0x136f, 1)> FreeVfFrequency6 = <FineTuningFunctions.FreeVfFrequency6: (0x1371, 1)> FreeVfFrequency7 = <FineTuningFunctions.FreeVfFrequency7: (0x1373, 1)> FreeVfVoltage1 = <FineTuningFunctions.FreeVfVoltage1: (0x1368, 1)> FreeVfVoltage2 = <FineTuningFunctions.FreeVfVoltage2: (0x136a, 1)> FreeVfVoltage3 = <FineTuningFunctions.FreeVfVoltage3: (0x136c, 1)> FreeVfVoltage4 = <FineTuningFunctions.FreeVfVoltage4: (0x136e, 1)> FreeVfVoltage5 = <FineTuningFunctions.FreeVfVoltage5: (0x1370, 1)> FreeVfVoltage6 = <FineTuningFunctions.FreeVfVoltage6: (0x1372, 1)> FreeVfVoltage7 = <FineTuningFunctions.FreeVfVoltage7: (0x1374, 1)> FrequencyConversionCoefficient = <FineTuningFunctions.FrequencyConversionCoefficient: (0x1359, 1)> FrequencyMatchingLowerLimit = <FineTuningFunctions.FrequencyMatchingLowerLimit: (0x1307, 2)> FrequencySetInMonitoring = <FineTuningFunctions.FrequencySetInMonitoring: (0x13a6, 1)> GSInputMode = <FineTuningFunctions.GSInputMode: (0x1394, 1)> InitialScreenSelection = <FineTuningFunctions.InitialScreenSelection: (0x1328, 1)> InitializationParameterSelection = <FineTuningFunctions.InitializationParameterSelection: (0x1358, 1)> InitializationSelection = <FineTuningFunctions.InitializationSelection: (0x1357, 1)> InitializationTargetData = <FineTuningFunctions.InitializationTargetData: (0x1361, 1)> InitializeTrigger = <FineTuningFunctions.InitializeTrigger: (0x13b7, 1)> IntegratedPowerClear = <FineTuningFunctions.IntegratedPowerClear: (0x1351, 1)> IntegratedPowerDisplayGain = <FineTuningFunctions.IntegratedPowerDisplayGain: (0x1352, 1)> InverterModeSelection = <FineTuningFunctions.InverterModeSelection: (0x13ae, 1)> MomentaryPowerInterruptionRetryTimeSelection = <FineTuningFunctions.MomentaryPowerInterruptionRetryTimeSelection: (0x1305, 1)> MotorCableLengthParameter = <FineTuningFunctions.MotorCableLengthParameter: (0x1322, 1)> NonStopFunctionOnPowerInterruptionSelection = <FineTuningFunctions.NonStopFunctionOnPowerInterruptionSelection: (0x1334, 1)> OvercurrentSuppressionFunction = <FineTuningFunctions.OvercurrentSuppressionFunction: (0x131c, 1)> OverloadLimitLevel = <FineTuningFunctions.OverloadLimitLevel: (0x1317, 1)> OverloadLimitLevel2 = <FineTuningFunctions.OverloadLimitLevel2: (0x131a, 1)> OverloadLimitParameter = <FineTuningFunctions.OverloadLimitParameter: (0x1318, 1)> OverloadLimitParameter2 = <FineTuningFunctions.OverloadLimitParameter2: (0x131b, 1)> OverloadLimitSelection = <FineTuningFunctions.OverloadLimitSelection: (0x1316, 1)> OverloadLimitSelection2 = <FineTuningFunctions.OverloadLimitSelection2: (0x1319, 1)> OvervoltageProtectionDuringDeceleration = <FineTuningFunctions.OvervoltageProtectionDuringDeceleration: (0x1385, 1)> OvervoltageProtectionIntegralGain = <FineTuningFunctions.OvervoltageProtectionIntegralGain: (0x1389, 1)> OvervoltageProtectionLevelDuringDeceleration = <FineTuningFunctions.OvervoltageProtectionLevelDuringDeceleration: (0x1386, 1)> OvervoltageProtectionParameter = <FineTuningFunctions.OvervoltageProtectionParameter: (0x1387, 1)> OvervoltageProtectionProportionalGain = <FineTuningFunctions.OvervoltageProtectionProportionalGain: (0x1388, 1)> OvervoltageRetryTimeSelection = <FineTuningFunctions.OvervoltageRetryTimeSelection: (0x130b, 1)> PowerOnTimeSetting = <FineTuningFunctions.PowerOnTimeSetting: (0x1323, 2)> RateOfRegenerativeBrakingFunction = <FineTuningFunctions.RateOfRegenerativeBrakingFunction: (0x135d, 1)> ReducedVoltageStartupSelection = <FineTuningFunctions.ReducedVoltageStartupSelection: (0x1326, 1)> RegenerativeBrakingONLevel = <FineTuningFunctions.RegenerativeBrakingONLevel: (0x1363, 1)> RegenerativeBrakingOperation = <FineTuningFunctions.RegenerativeBrakingOperation: (0x1362, 1)> RetrySelection = <FineTuningFunctions.RetrySelection: (0x1301, 1)> RetryWaitTime = <FineTuningFunctions.RetryWaitTime: (0x1303, 1)> ReverseRotationPreventionSelection = <FineTuningFunctions.ReverseRotationPreventionSelection: (0x1330, 1)> RotationDirectionLimitSelection = <FineTuningFunctions.RotationDirectionLimitSelection: (0x1325, 1)> SecondDualMonitorParameter = <FineTuningFunctions.SecondDualMonitorParameter: (0x13a4, 1)> SoftLockSelection = <FineTuningFunctions.SoftLockSelection: (0x1320, 1)> StartingFrequency = <FineTuningFunctions.StartingFrequency: (0x1355, 1)> StartingFrequencyAtActiveFrequencyMatchingRestart = <FineTuningFunctions.StartingFrequencyAtActiveFrequencyMatchingRestart: (0x131f, 1)> StartingVoltageOfNonStopFunction = <FineTuningFunctions.StartingVoltageOfNonStopFunction: (0x1335, 1)> StopDecelerationLevelOfNonStopFunction = <FineTuningFunctions.StopDecelerationLevelOfNonStopFunction: (0x1336, 1)> StopKeySelection = <FineTuningFunctions.StopKeySelection: (0x135a, 1)> StopSelection = <FineTuningFunctions.StopSelection: (0x135e, 1)> ThermalAccumulatorGain = <FineTuningFunctions.ThermalAccumulatorGain: (0x13cb, 1)> ThermalDecrementMode = <FineTuningFunctions.ThermalDecrementMode: (0x13c6, 1)> ThermalDecrementTime = <FineTuningFunctions.ThermalDecrementTime: (0x13c7, 2)> ThermalDecrementTimeConstant = <FineTuningFunctions.ThermalDecrementTimeConstant: (0x13c9, 2)> TorqueLADSTOPSelection = <FineTuningFunctions.TorqueLADSTOPSelection: (0x132f, 1)> TorqueLimit1 = <FineTuningFunctions.TorqueLimit1: (0x132b, 1)> TorqueLimit2 = <FineTuningFunctions.TorqueLimit2: (0x132c, 1)> TorqueLimit3 = <FineTuningFunctions.TorqueLimit3: (0x132d, 1)> TorqueLimit4 = <FineTuningFunctions.TorqueLimit4: (0x132e, 1)> TorqueLimitSelection = <FineTuningFunctions.TorqueLimitSelection: (0x132a, 1)> TripRetrySelection = <FineTuningFunctions.TripRetrySelection: (0x1309, 1)> TripRetryWaitTime = <FineTuningFunctions.TripRetryWaitTime: (0x130c, 1)> UndervoltageTripDuringStopSelection = <FineTuningFunctions.UndervoltageTripDuringStopSelection: (0x1304, 1)> UserParameterAutomaticSettingFunctionSelection = <FineTuningFunctions.UserParameterAutomaticSettingFunctionSelection: (0x1329, 1)> WindowComparatorCurrentHysteresisWidth = <FineTuningFunctions.WindowComparatorCurrentHysteresisWidth: (0x1344, 1)> WindowComparatorLowerCurrentLevel = <FineTuningFunctions.WindowComparatorLowerCurrentLevel: (0x1343, 1)> WindowComparatorLowerVoltageLevel = <FineTuningFunctions.WindowComparatorLowerVoltageLevel: (0x1340, 1)> WindowComparatorUpperCurrentLevel = <FineTuningFunctions.WindowComparatorUpperCurrentLevel: (0x1342, 1)> WindowComparatorUpperVoltageLevel = <FineTuningFunctions.WindowComparatorUpperVoltageLevel: (0x133f, 1)> WindowComparatorVoltageHysteresisWidth = <FineTuningFunctions.WindowComparatorVoltageHysteresisWidth: (0x1341, 1)> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
class FunctionCode(enum.IntEnum)
`` | `FunctionCode(value, names=None, *, module=None, qualname=None, type=None, start=1) Function codes (2nd byte of Modbus message). See datasheet section B-3, p. 299.`
| Method resolution order: FunctionCode enum.IntEnum builtins.int enum.Enum builtins.object Data and other attributes defined here: LoopbackTest = <FunctionCode.LoopbackTest: 8> ReadCoilStatus = <FunctionCode.ReadCoilStatus: 1> ReadHoldingRegister = <FunctionCode.ReadHoldingRegister: 3> ReadWriteRegisters = <FunctionCode.ReadWriteRegisters: 23> WriteInCoil = <FunctionCode.WriteInCoil: 5> WriteInHoldingRegister = <FunctionCode.WriteInHoldingRegister: 6> WriteInMultipleCoils = <FunctionCode.WriteInMultipleCoils: 15> WriteInRegisters = <FunctionCode.WriteInRegisters: 16> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
GroupA = class StandardFunctions(Register)
`` | `GroupA(value, names=None, *, module=None, qualname=None, type=None, start=1) Standard function group. See datasheet sections 3-5 (pp. 90-120) and B-4 (pp. 324-327).`
| Method resolution order: StandardFunctions Register enum.Enum builtins.object Data and other attributes defined here: AVRDecelerationGain = <StandardFunctions.AVRDecelerationGain: (0x126c, 1)> AVRFilterTimeConstant = <StandardFunctions.AVRFilterTimeConstant: (0x126b, 1)> AVRSelection = <StandardFunctions.AVRSelection: (0x1269, 1)> AVRVoltageSelection = <StandardFunctions.AVRVoltageSelection: (0x126a, 1)> Acc1ToAcc2FrequencyTransitionPoint = <StandardFunctions.Acc1ToAcc2FrequencyTransitionPoint: (0x1279, 2)> AccelerationCurveParameter = <StandardFunctions.AccelerationCurveParameter: (0x12a5, 1)> AccelerationCurveSelection = <StandardFunctions.AccelerationCurveSelection: (0x127d, 1)> AccelerationStopFrequency = <StandardFunctions.AccelerationStopFrequency: (0x125c, 2)> AccelerationStopTime = <StandardFunctions.AccelerationStopTime: (0x125e, 1)> AccelerationTime2 = <StandardFunctions.AccelerationTime2: (0x1274, 2)> AutomaticTorqueBoostSlipCompensationGain = <StandardFunctions.AutomaticTorqueBoostSlipCompensationGain: (0x1241, 1)> AutomaticTorqueBoostVoltageCompensationGain = <StandardFunctions.AutomaticTorqueBoostVoltageCompensationGain: (0x1240, 1)> BaseFrequency = <StandardFunctions.BaseFrequency: (0x1203, 1)> CurrentInputActiveRangeEndFrequency = <StandardFunctions.CurrentInputActiveRangeEndFrequency: (0x1283, 2)> CurrentInputActiveRangeEndRatio = <StandardFunctions.CurrentInputActiveRangeEndRatio: (0x1286, 1)> CurrentInputActiveRangeStartFrequency = <StandardFunctions.CurrentInputActiveRangeStartFrequency: (0x1281, 2)> CurrentInputActiveRangeStartRatio = <StandardFunctions.CurrentInputActiveRangeStartRatio: (0x1285, 1)> CurrentInputStartFrequencyEnable = <StandardFunctions.CurrentInputStartFrequencyEnable: (0x1287, 1)> DCInjectionBrakingCarrierFrequency = <StandardFunctions.DCInjectionBrakingCarrierFrequency: (0x124d, 1)> DCInjectionBrakingDelayTime = <StandardFunctions.DCInjectionBrakingDelayTime: (0x1247, 1)> DCInjectionBrakingEnable = <StandardFunctions.DCInjectionBrakingEnable: (0x1245, 1)> DCInjectionBrakingFrequency = <StandardFunctions.DCInjectionBrakingFrequency: (0x1246, 1)> DCInjectionBrakingMethodSelection = <StandardFunctions.DCInjectionBrakingMethodSelection: (0x124a, 1)> DCInjectionBrakingPower = <StandardFunctions.DCInjectionBrakingPower: (0x1248, 1)> DCInjectionBrakingTime = <StandardFunctions.DCInjectionBrakingTime: (0x1249, 1)> Dec1ToDec2FrequencyTransitionPoint = <StandardFunctions.Dec1ToDec2FrequencyTransitionPoint: (0x127b, 2)> DecelerationCurveParameter = <StandardFunctions.DecelerationCurveParameter: (0x12a6, 1)> DecelerationCurveSelection = <StandardFunctions.DecelerationCurveSelection: (0x127e, 1)> DecelerationHoldFrequency = <StandardFunctions.DecelerationHoldFrequency: (0x12bd, 2)> DecelerationHoldTime = <StandardFunctions.DecelerationHoldTime: (0x12bf, 1)> DecelerationTime2 = <StandardFunctions.DecelerationTime2: (0x1276, 2)> DriveProgramming = <StandardFunctions.DriveProgramming: (0x1213, 1)> ELSCurveRatio1DuringAcceleration = <StandardFunctions.ELSCurveRatio1DuringAcceleration: (0x12b9, 1)> ELSCurveRatio1DuringDeceleration = <StandardFunctions.ELSCurveRatio1DuringDeceleration: (0x12bb, 1)> ELSCurveRatio2DuringAcceleration = <StandardFunctions.ELSCurveRatio2DuringAcceleration: (0x12ba, 1)> ELSCurveRatio2DuringDeceleration = <StandardFunctions.ELSCurveRatio2DuringDeceleration: (0x12bc, 1)> EnergySavingOperationMode = <StandardFunctions.EnergySavingOperationMode: (0x126d, 1)> EnergySavingResponseAccuracyAdjustment = <StandardFunctions.EnergySavingResponseAccuracyAdjustment: (0x126e, 1)> ExternalFrequencyFilterTimeConstant = <StandardFunctions.ExternalFrequencyFilterTimeConstant: (0x1212, 1)> FrequencyAdditionAmount = <StandardFunctions.FrequencyAdditionAmount: (0x12b3, 2)> FrequencyAdditionDirection = <StandardFunctions.FrequencyAdditionDirection: (0x12b5, 1)> FrequencyLowerLimit = <StandardFunctions.FrequencyLowerLimit: (0x1251, 2)> FrequencyReferenceSelection = <StandardFunctions.FrequencyReferenceSelection: (0x1201, 1)> FrequencyUpperLimit = <StandardFunctions.FrequencyUpperLimit: (0x124f, 2)> IOVoltageCurrentSelection = <StandardFunctions.IOVoltageCurrentSelection: (0x1205, 1)> JoggingFrequency = <StandardFunctions.JoggingFrequency: (0x1238, 1)> JoggingStopSelection = <StandardFunctions.JoggingStopSelection: (0x1239, 1)> JumpFrequency1 = <StandardFunctions.JumpFrequency1: (0x1253, 2)> JumpFrequency2 = <StandardFunctions.JumpFrequency2: (0x1256, 2)> JumpFrequency3 = <StandardFunctions.JumpFrequency3: (0x1259, 2)> JumpFrequencyWidth1 = <StandardFunctions.JumpFrequencyWidth1: (0x1255, 1)> JumpFrequencyWidth2 = <StandardFunctions.JumpFrequencyWidth2: (0x1258, 1)> JumpFrequencyWidth3 = <StandardFunctions.JumpFrequencyWidth3: (0x125b, 1)> ManualTorqueBoostFrequency = <StandardFunctions.ManualTorqueBoostFrequency: (0x123d, 1)> ManualTorqueBoostVoltage = <StandardFunctions.ManualTorqueBoostVoltage: (0x123c, 1)> MaximumFrequency = <StandardFunctions.MaximumFrequency: (0x1204, 1)> MethodToSwitchToAcc2Dec2 = <StandardFunctions.MethodToSwitchToAcc2Dec2: (0x1278, 1)> MultiStepSpeedReference0 = <StandardFunctions.MultiStepSpeedReference0: (0x1216, 2)> MultiStepSpeedReference1 = <StandardFunctions.MultiStepSpeedReference1: (0x1218, 2)> MultiStepSpeedReference10 = <StandardFunctions.MultiStepSpeedReference10: (0x122a, 2)> MultiStepSpeedReference11 = <StandardFunctions.MultiStepSpeedReference11: (0x122c, 2)> MultiStepSpeedReference12 = <StandardFunctions.MultiStepSpeedReference12: (0x122e, 2)> MultiStepSpeedReference13 = <StandardFunctions.MultiStepSpeedReference13: (0x1230, 2)> MultiStepSpeedReference14 = <StandardFunctions.MultiStepSpeedReference14: (0x1232, 2)> MultiStepSpeedReference15 = <StandardFunctions.MultiStepSpeedReference15: (0x1234, 2)> MultiStepSpeedReference2 = <StandardFunctions.MultiStepSpeedReference2: (0x121a, 2)> MultiStepSpeedReference3 = <StandardFunctions.MultiStepSpeedReference3: (0x121c, 2)> MultiStepSpeedReference4 = <StandardFunctions.MultiStepSpeedReference4: (0x121e, 2)> MultiStepSpeedReference5 = <StandardFunctions.MultiStepSpeedReference5: (0x1220, 2)> MultiStepSpeedReference6 = <StandardFunctions.MultiStepSpeedReference6: (0x1222, 2)> MultiStepSpeedReference7 = <StandardFunctions.MultiStepSpeedReference7: (0x1224, 2)> MultiStepSpeedReference8 = <StandardFunctions.MultiStepSpeedReference8: (0x1226, 2)> MultiStepSpeedReference9 = <StandardFunctions.MultiStepSpeedReference9: (0x1228, 2)> MultiStepSpeedSelection = <StandardFunctions.MultiStepSpeedSelection: (0x1215, 1)> OperationFrequencyInputASelection = <StandardFunctions.OperationFrequencyInputASelection: (0x12af, 1)> OperationFrequencyInputBSelection = <StandardFunctions.OperationFrequencyInputBSelection: (0x12b0, 1)> OperationSelection = <StandardFunctions.OperationSelection: (0x12b1, 1)> OutputVoltageGain = <StandardFunctions.OutputVoltageGain: (0x123f, 1)> PIDDGain = <StandardFunctions.PIDDGain: (0x1262, 1)> PIDFeedForwardSelection = <StandardFunctions.PIDFeedForwardSelection: (0x1267, 1)> PIDFeedbackSelection = <StandardFunctions.PIDFeedbackSelection: (0x1264, 1)> PIDIGain = <StandardFunctions.PIDIGain: (0x1261, 1)> PIDOutputLimitFunction = <StandardFunctions.PIDOutputLimitFunction: (0x1266, 1)> PIDPGain = <StandardFunctions.PIDPGain: (0x1260, 1)> PIDScale = <StandardFunctions.PIDScale: (0x1263, 1)> PIDSelection = <StandardFunctions.PIDSelection: (0x125f, 1)> PIDSleepFunctionActionDelayTime = <StandardFunctions.PIDSleepFunctionActionDelayTime: (0x12c2, 1)> PIDSleepFunctionActionThreshold = <StandardFunctions.PIDSleepFunctionActionThreshold: (0x12c0, 2)> ReversePIDFunction = <StandardFunctions.ReversePIDFunction: (0x1265, 1)> RunCommandSelection = <StandardFunctions.RunCommandSelection: (0x1202, 1)> StartupDCInjectionBrakingPower = <StandardFunctions.StartupDCInjectionBrakingPower: (0x124b, 1)> StartupDCInjectionBrakingTime = <StandardFunctions.StartupDCInjectionBrakingTime: (0x124c, 1)> TorqueBoostSelection = <StandardFunctions.TorqueBoostSelection: (0x123b, 1)> VFCharacteristicsSelection = <StandardFunctions.VFCharacteristicsSelection: (0x123e, 1)> VRInputActiveRangeEndFrequency = <StandardFunctions.VRInputActiveRangeEndFrequency: (0x12c8, 2)> VRInputActiveRangeEndVoltage = <StandardFunctions.VRInputActiveRangeEndVoltage: (0x12cb, 1)> VRInputActiveRangeStartCurrent = <StandardFunctions.VRInputActiveRangeStartCurrent: (0x12ca, 1)> VRInputActiveRangeStartFrequency = <StandardFunctions.VRInputActiveRangeStartFrequency: (0x12c6, 2)> VRInputStartFrequencyEnable = <StandardFunctions.VRInputStartFrequencyEnable: (0x12cc, 1)> VoltageEndFrequency = <StandardFunctions.VoltageEndFrequency: (0x120d, 2)> VoltageEndRatio = <StandardFunctions.VoltageEndRatio: (0x1210, 1)> VoltageStartFrequency = <StandardFunctions.VoltageStartFrequency: (0x120b, 2)> VoltageStartRatio = <StandardFunctions.VoltageStartRatio: (0x120f, 1)> VoltageStartSelection = <StandardFunctions.VoltageStartSelection: (0x1211, 1)> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
GroupB = class FineTuningFunctions(Register)
`` | `GroupB(value, names=None, *, module=None, qualname=None, type=None, start=1) Fine tuning function group. See datasheet sections 3-6 (pp. 121-153) and B-4 (pp. 328-331).`
| Method resolution order: FineTuningFunctions Register enum.Enum builtins.object Data and other attributes defined here: ActiveFrequencyMatchingRestartLevel = <FineTuningFunctions.ActiveFrequencyMatchingRestartLevel: (0x131d, 1)> ActiveFrequencyMatchingRestartParameter = <FineTuningFunctions.ActiveFrequencyMatchingRestartParameter: (0x131e, 1)> AllowableMomentaryPowerInterruptionTime = <FineTuningFunctions.AllowableMomentaryPowerInterruptionTime: (0x1302, 1)> AmbientTemperature = <FineTuningFunctions.AmbientTemperature: (0x134e, 1)> AnalogCurrentLevelAtDisconnection = <FineTuningFunctions.AnalogCurrentLevelAtDisconnection: (0x134a, 1)> AnalogVoltageLevelAtDisconnection = <FineTuningFunctions.AnalogVoltageLevelAtDisconnection: (0x1349, 1)> AutoReturnInitialDisplay = <FineTuningFunctions.AutoReturnInitialDisplay: (0x13a7, 1)> AutomaticCarrierFrequencyReduction = <FineTuningFunctions.AutomaticCarrierFrequencyReduction: (0x135c, 1)> BRDResistor = <FineTuningFunctions.BRDResistor: (0x1364, 1)> BrakeControlSelection = <FineTuningFunctions.BrakeControlSelection: (0x137b, 1)> BrakeInputFrequency = <FineTuningFunctions.BrakeInputFrequency: (0x1382, 1)> BrakeReleaseCurrent = <FineTuningFunctions.BrakeReleaseCurrent: (0x1381, 1)> BrakeReleaseFrequency = <FineTuningFunctions.BrakeReleaseFrequency: (0x1380, 1)> BrakeWaitTimeForAcceleration = <FineTuningFunctions.BrakeWaitTimeForAcceleration: (0x137d, 1)> BrakeWaitTimeForConfirmation = <FineTuningFunctions.BrakeWaitTimeForConfirmation: (0x137f, 1)> BrakeWaitTimeForRelease = <FineTuningFunctions.BrakeWaitTimeForRelease: (0x137c, 1)> BrakeWaitTimeForStopping = <FineTuningFunctions.BrakeWaitTimeForStopping: (0x137e, 1)> CarrierFrequency = <FineTuningFunctions.CarrierFrequency: (0x1356, 1)> ClearElapsedTimeOfCoolingFan = <FineTuningFunctions.ClearElapsedTimeOfCoolingFan: (0x1360, 1)> CoolingFanControl = <FineTuningFunctions.CoolingFanControl: (0x135f, 1)> DataReadWriteSelection = <FineTuningFunctions.DataReadWriteSelection: (0x13a9, 1)> DecelerationStartingWidthOfNonStopFunction = <FineTuningFunctions.DecelerationStartingWidthOfNonStopFunction: (0x1339, 1)> DecelerationTimeOfNonStopFunction = <FineTuningFunctions.DecelerationTimeOfNonStopFunction: (0x1337, 2)> DisplayExternalOperatorConnected = <FineTuningFunctions.DisplayExternalOperatorConnected: (0x139a, 1)> DisplaySelection = <FineTuningFunctions.DisplaySelection: (0x1327, 1)> DualRateSelection = <FineTuningFunctions.DualRateSelection: (0x1333, 1)> ElectronicThermalCharacteristicsSelection = <FineTuningFunctions.ElectronicThermalCharacteristicsSelection: (0x130e, 1)> ElectronicThermalCurrent1 = <FineTuningFunctions.ElectronicThermalCurrent1: (0x1311, 1)> ElectronicThermalCurrent2 = <FineTuningFunctions.ElectronicThermalCurrent2: (0x1313, 1)> ElectronicThermalCurrent3 = <FineTuningFunctions.ElectronicThermalCurrent3: (0x1315, 1)> ElectronicThermalFrequency1 = <FineTuningFunctions.ElectronicThermalFrequency1: (0x1310, 1)> ElectronicThermalFrequency2 = <FineTuningFunctions.ElectronicThermalFrequency2: (0x1312, 1)> ElectronicThermalFrequency3 = <FineTuningFunctions.ElectronicThermalFrequency3: (0x1314, 1)> ElectronicThermalLevel = <FineTuningFunctions.ElectronicThermalLevel: (0x130d, 1)> ExternalOperatorDisconnectionAction = <FineTuningFunctions.ExternalOperatorDisconnectionAction: (0x13a8, 1)> FirstDualMonitorParameter = <FineTuningFunctions.FirstDualMonitorParameter: (0x13a3, 1)> FreeRunStopSelection = <FineTuningFunctions.FreeRunStopSelection: (0x135b, 1)> FreeVfFrequency1 = <FineTuningFunctions.FreeVfFrequency1: (0x1367, 1)> FreeVfFrequency2 = <FineTuningFunctions.FreeVfFrequency2: (0x1369, 1)> FreeVfFrequency3 = <FineTuningFunctions.FreeVfFrequency3: (0x136b, 1)> FreeVfFrequency4 = <FineTuningFunctions.FreeVfFrequency4: (0x136d, 1)> FreeVfFrequency5 = <FineTuningFunctions.FreeVfFrequency5: (0x136f, 1)> FreeVfFrequency6 = <FineTuningFunctions.FreeVfFrequency6: (0x1371, 1)> FreeVfFrequency7 = <FineTuningFunctions.FreeVfFrequency7: (0x1373, 1)> FreeVfVoltage1 = <FineTuningFunctions.FreeVfVoltage1: (0x1368, 1)> FreeVfVoltage2 = <FineTuningFunctions.FreeVfVoltage2: (0x136a, 1)> FreeVfVoltage3 = <FineTuningFunctions.FreeVfVoltage3: (0x136c, 1)> FreeVfVoltage4 = <FineTuningFunctions.FreeVfVoltage4: (0x136e, 1)> FreeVfVoltage5 = <FineTuningFunctions.FreeVfVoltage5: (0x1370, 1)> FreeVfVoltage6 = <FineTuningFunctions.FreeVfVoltage6: (0x1372, 1)> FreeVfVoltage7 = <FineTuningFunctions.FreeVfVoltage7: (0x1374, 1)> FrequencyConversionCoefficient = <FineTuningFunctions.FrequencyConversionCoefficient: (0x1359, 1)> FrequencyMatchingLowerLimit = <FineTuningFunctions.FrequencyMatchingLowerLimit: (0x1307, 2)> FrequencySetInMonitoring = <FineTuningFunctions.FrequencySetInMonitoring: (0x13a6, 1)> GSInputMode = <FineTuningFunctions.GSInputMode: (0x1394, 1)> InitialScreenSelection = <FineTuningFunctions.InitialScreenSelection: (0x1328, 1)> InitializationParameterSelection = <FineTuningFunctions.InitializationParameterSelection: (0x1358, 1)> InitializationSelection = <FineTuningFunctions.InitializationSelection: (0x1357, 1)> InitializationTargetData = <FineTuningFunctions.InitializationTargetData: (0x1361, 1)> InitializeTrigger = <FineTuningFunctions.InitializeTrigger: (0x13b7, 1)> IntegratedPowerClear = <FineTuningFunctions.IntegratedPowerClear: (0x1351, 1)> IntegratedPowerDisplayGain = <FineTuningFunctions.IntegratedPowerDisplayGain: (0x1352, 1)> InverterModeSelection = <FineTuningFunctions.InverterModeSelection: (0x13ae, 1)> MomentaryPowerInterruptionRetryTimeSelection = <FineTuningFunctions.MomentaryPowerInterruptionRetryTimeSelection: (0x1305, 1)> MotorCableLengthParameter = <FineTuningFunctions.MotorCableLengthParameter: (0x1322, 1)> NonStopFunctionOnPowerInterruptionSelection = <FineTuningFunctions.NonStopFunctionOnPowerInterruptionSelection: (0x1334, 1)> OvercurrentSuppressionFunction = <FineTuningFunctions.OvercurrentSuppressionFunction: (0x131c, 1)> OverloadLimitLevel = <FineTuningFunctions.OverloadLimitLevel: (0x1317, 1)> OverloadLimitLevel2 = <FineTuningFunctions.OverloadLimitLevel2: (0x131a, 1)> OverloadLimitParameter = <FineTuningFunctions.OverloadLimitParameter: (0x1318, 1)> OverloadLimitParameter2 = <FineTuningFunctions.OverloadLimitParameter2: (0x131b, 1)> OverloadLimitSelection = <FineTuningFunctions.OverloadLimitSelection: (0x1316, 1)> OverloadLimitSelection2 = <FineTuningFunctions.OverloadLimitSelection2: (0x1319, 1)> OvervoltageProtectionDuringDeceleration = <FineTuningFunctions.OvervoltageProtectionDuringDeceleration: (0x1385, 1)> OvervoltageProtectionIntegralGain = <FineTuningFunctions.OvervoltageProtectionIntegralGain: (0x1389, 1)> OvervoltageProtectionLevelDuringDeceleration = <FineTuningFunctions.OvervoltageProtectionLevelDuringDeceleration: (0x1386, 1)> OvervoltageProtectionParameter = <FineTuningFunctions.OvervoltageProtectionParameter: (0x1387, 1)> OvervoltageProtectionProportionalGain = <FineTuningFunctions.OvervoltageProtectionProportionalGain: (0x1388, 1)> OvervoltageRetryTimeSelection = <FineTuningFunctions.OvervoltageRetryTimeSelection: (0x130b, 1)> PowerOnTimeSetting = <FineTuningFunctions.PowerOnTimeSetting: (0x1323, 2)> RateOfRegenerativeBrakingFunction = <FineTuningFunctions.RateOfRegenerativeBrakingFunction: (0x135d, 1)> ReducedVoltageStartupSelection = <FineTuningFunctions.ReducedVoltageStartupSelection: (0x1326, 1)> RegenerativeBrakingONLevel = <FineTuningFunctions.RegenerativeBrakingONLevel: (0x1363, 1)> RegenerativeBrakingOperation = <FineTuningFunctions.RegenerativeBrakingOperation: (0x1362, 1)> RetrySelection = <FineTuningFunctions.RetrySelection: (0x1301, 1)> RetryWaitTime = <FineTuningFunctions.RetryWaitTime: (0x1303, 1)> ReverseRotationPreventionSelection = <FineTuningFunctions.ReverseRotationPreventionSelection: (0x1330, 1)> RotationDirectionLimitSelection = <FineTuningFunctions.RotationDirectionLimitSelection: (0x1325, 1)> SecondDualMonitorParameter = <FineTuningFunctions.SecondDualMonitorParameter: (0x13a4, 1)> SoftLockSelection = <FineTuningFunctions.SoftLockSelection: (0x1320, 1)> StartingFrequency = <FineTuningFunctions.StartingFrequency: (0x1355, 1)> StartingFrequencyAtActiveFrequencyMatchingRestart = <FineTuningFunctions.StartingFrequencyAtActiveFrequencyMatchingRestart: (0x131f, 1)> StartingVoltageOfNonStopFunction = <FineTuningFunctions.StartingVoltageOfNonStopFunction: (0x1335, 1)> StopDecelerationLevelOfNonStopFunction = <FineTuningFunctions.StopDecelerationLevelOfNonStopFunction: (0x1336, 1)> StopKeySelection = <FineTuningFunctions.StopKeySelection: (0x135a, 1)> StopSelection = <FineTuningFunctions.StopSelection: (0x135e, 1)> ThermalAccumulatorGain = <FineTuningFunctions.ThermalAccumulatorGain: (0x13cb, 1)> ThermalDecrementMode = <FineTuningFunctions.ThermalDecrementMode: (0x13c6, 1)> ThermalDecrementTime = <FineTuningFunctions.ThermalDecrementTime: (0x13c7, 2)> ThermalDecrementTimeConstant = <FineTuningFunctions.ThermalDecrementTimeConstant: (0x13c9, 2)> TorqueLADSTOPSelection = <FineTuningFunctions.TorqueLADSTOPSelection: (0x132f, 1)> TorqueLimit1 = <FineTuningFunctions.TorqueLimit1: (0x132b, 1)> TorqueLimit2 = <FineTuningFunctions.TorqueLimit2: (0x132c, 1)> TorqueLimit3 = <FineTuningFunctions.TorqueLimit3: (0x132d, 1)> TorqueLimit4 = <FineTuningFunctions.TorqueLimit4: (0x132e, 1)> TorqueLimitSelection = <FineTuningFunctions.TorqueLimitSelection: (0x132a, 1)> TripRetrySelection = <FineTuningFunctions.TripRetrySelection: (0x1309, 1)> TripRetryWaitTime = <FineTuningFunctions.TripRetryWaitTime: (0x130c, 1)> UndervoltageTripDuringStopSelection = <FineTuningFunctions.UndervoltageTripDuringStopSelection: (0x1304, 1)> UserParameterAutomaticSettingFunctionSelection = <FineTuningFunctions.UserParameterAutomaticSettingFunctionSelection: (0x1329, 1)> WindowComparatorCurrentHysteresisWidth = <FineTuningFunctions.WindowComparatorCurrentHysteresisWidth: (0x1344, 1)> WindowComparatorLowerCurrentLevel = <FineTuningFunctions.WindowComparatorLowerCurrentLevel: (0x1343, 1)> WindowComparatorLowerVoltageLevel = <FineTuningFunctions.WindowComparatorLowerVoltageLevel: (0x1340, 1)> WindowComparatorUpperCurrentLevel = <FineTuningFunctions.WindowComparatorUpperCurrentLevel: (0x1342, 1)> WindowComparatorUpperVoltageLevel = <FineTuningFunctions.WindowComparatorUpperVoltageLevel: (0x133f, 1)> WindowComparatorVoltageHysteresisWidth = <FineTuningFunctions.WindowComparatorVoltageHysteresisWidth: (0x1341, 1)> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
GroupC = class IntelligentTerminalFunctions(Register)
`` | `GroupC(value, names=None, *, module=None, qualname=None, type=None, start=1) Intelligent terminal function group. See datasheet sections 3-7 (pp. 153-171) and B-4 (pp. 332-336).`
| Method resolution order: IntelligentTerminalFunctions Register enum.Enum builtins.object Data and other attributes defined here: AMBias = <IntelligentTerminalFunctions.AMBias: (0x1471, 1)> AMGain = <IntelligentTerminalFunctions.AMGain: (0x146e, 1)> AMTerminalFunction = <IntelligentTerminalFunctions.AMTerminalFunction: (0x141c, 1)> BaudRate = <IntelligentTerminalFunctions.BaudRate: (0x144b, 1)> CommunicationErrorEffect = <IntelligentTerminalFunctions.CommunicationErrorEffect: (0x1450, 1)> CommunicationErrorTimeout = <IntelligentTerminalFunctions.CommunicationErrorTimeout: (0x1451, 1)> CommunicationParity = <IntelligentTerminalFunctions.CommunicationParity: (0x144e, 1)> CommunicationSelection = <IntelligentTerminalFunctions.CommunicationSelection: (0x1464, 1)> CommunicationStopBits = <IntelligentTerminalFunctions.CommunicationStopBits: (0x144f, 1)> CommunicationWaitTime = <IntelligentTerminalFunctions.CommunicationWaitTime: (0x1452, 1)> CurrentMonitorReferenceValue = <IntelligentTerminalFunctions.CurrentMonitorReferenceValue: (0x141e, 1)> DebugMode = <IntelligentTerminalFunctions.DebugMode: (0x145f, 1)> DeviceID = <IntelligentTerminalFunctions.DeviceID: (0x144c, 1)> EOGain = <IntelligentTerminalFunctions.EOGain: (0x146d, 1)> EOOutputPulseTrainScaleConversion = <IntelligentTerminalFunctions.EOOutputPulseTrainScaleConversion: (0x1433, 1)> EOTerminalFunction = <IntelligentTerminalFunctions.EOTerminalFunction: (0x141b, 1)> EzCOMMasterEndAddress = <IntelligentTerminalFunctions.EzCOMMasterEndAddress: (0x1467, 1)> EzCOMMasterStartAddress = <IntelligentTerminalFunctions.EzCOMMasterStartAddress: (0x1466, 1)> EzCOMStartingTrigger = <IntelligentTerminalFunctions.EzCOMStartingTrigger: (0x1468, 1)> FinOverheatWarningLevel = <IntelligentTerminalFunctions.FinOverheatWarningLevel: (0x1444, 1)> ForwardPowerRunningOvertorqueLevel = <IntelligentTerminalFunctions.ForwardPowerRunningOvertorqueLevel: (0x143b, 1)> ForwardRegenerationOvertorqueLevel = <IntelligentTerminalFunctions.ForwardRegenerationOvertorqueLevel: (0x143e, 1)> InputTerminalResponseTime1 = <IntelligentTerminalFunctions.InputTerminalResponseTime1: (0x14a4, 1)> InputTerminalResponseTime2 = <IntelligentTerminalFunctions.InputTerminalResponseTime2: (0x14a5, 1)> InputTerminalResponseTime3 = <IntelligentTerminalFunctions.InputTerminalResponseTime3: (0x14a6, 1)> InputTerminalResponseTime4 = <IntelligentTerminalFunctions.InputTerminalResponseTime4: (0x14a7, 1)> InputTerminalResponseTime5 = <IntelligentTerminalFunctions.InputTerminalResponseTime5: (0x14a8, 1)> InputTerminalResponseTime6 = <IntelligentTerminalFunctions.InputTerminalResponseTime6: (0x14a9, 1)> InputTerminalResponseTime7 = <IntelligentTerminalFunctions.InputTerminalResponseTime7: (0x14aa, 1)> LightLoadDetectionLevel = <IntelligentTerminalFunctions.LightLoadDetectionLevel: (0x1427, 1)> LightLoadSignalOutputMode = <IntelligentTerminalFunctions.LightLoadSignalOutputMode: (0x1426, 1)> LogicOutputSignal1OperatorSelection = <IntelligentTerminalFunctions.LogicOutputSignal1OperatorSelection: (0x1494, 1)> LogicOutputSignal1Selection1 = <IntelligentTerminalFunctions.LogicOutputSignal1Selection1: (0x1492, 1)> LogicOutputSignal1Selection2 = <IntelligentTerminalFunctions.LogicOutputSignal1Selection2: (0x1493, 1)> LogicOutputSignal2OperatorSelection = <IntelligentTerminalFunctions.LogicOutputSignal2OperatorSelection: (0x1497, 1)> LogicOutputSignal2Selection1 = <IntelligentTerminalFunctions.LogicOutputSignal2Selection1: (0x1495, 1)> LogicOutputSignal2Selection2 = <IntelligentTerminalFunctions.LogicOutputSignal2Selection2: (0x1496, 1)> LogicOutputSignal3OperatorSelection = <IntelligentTerminalFunctions.LogicOutputSignal3OperatorSelection: (0x149a, 1)> LogicOutputSignal3Selection1 = <IntelligentTerminalFunctions.LogicOutputSignal3Selection1: (0x1498, 1)> LogicOutputSignal3Selection2 = <IntelligentTerminalFunctions.LogicOutputSignal3Selection2: (0x1499, 1)> MultiFunctionInput1Function = <IntelligentTerminalFunctions.MultiFunctionInput1Function: (0x1401, 1)> MultiFunctionInput1Type = <IntelligentTerminalFunctions.MultiFunctionInput1Type: (0x140b, 1)> MultiFunctionInput2Function = <IntelligentTerminalFunctions.MultiFunctionInput2Function: (0x1402, 1)> MultiFunctionInput2Type = <IntelligentTerminalFunctions.MultiFunctionInput2Type: (0x140c, 1)> MultiFunctionInput3Function = <IntelligentTerminalFunctions.MultiFunctionInput3Function: (0x1403, 1)> MultiFunctionInput3Type = <IntelligentTerminalFunctions.MultiFunctionInput3Type: (0x140d, 1)> MultiFunctionInput4Function = <IntelligentTerminalFunctions.MultiFunctionInput4Function: (0x1404, 1)> MultiFunctionInput4Type = <IntelligentTerminalFunctions.MultiFunctionInput4Type: (0x140e, 1)> MultiFunctionInput5Function = <IntelligentTerminalFunctions.MultiFunctionInput5Function: (0x1405, 1)> MultiFunctionInput5Type = <IntelligentTerminalFunctions.MultiFunctionInput5Type: (0x140f, 1)> MultiFunctionInput6Function = <IntelligentTerminalFunctions.MultiFunctionInput6Function: (0x1406, 1)> MultiFunctionInput6Type = <IntelligentTerminalFunctions.MultiFunctionInput6Type: (0x1410, 1)> MultiFunctionInput7Function = <IntelligentTerminalFunctions.MultiFunctionInput7Function: (0x1407, 1)> MultiFunctionInput7Type = <IntelligentTerminalFunctions.MultiFunctionInput7Type: (0x1411, 1)> MultiFunctionOutput11Function = <IntelligentTerminalFunctions.MultiFunctionOutput11Function: (0x1415, 1)> MultiFunctionOutput11Type = <IntelligentTerminalFunctions.MultiFunctionOutput11Type: (0x141f, 1)> MultiFunctionOutput12Function = <IntelligentTerminalFunctions.MultiFunctionOutput12Function: (0x1416, 1)> MultiFunctionOutput12Type = <IntelligentTerminalFunctions.MultiFunctionOutput12Type: (0x1420, 1)> MultiStepSpeedPositionDeterminationTime = <IntelligentTerminalFunctions.MultiStepSpeedPositionDeterminationTime: (0x14ad, 1)> OAdjustment = <IntelligentTerminalFunctions.OAdjustment: (0x1455, 1)> OIAdjustment = <IntelligentTerminalFunctions.OIAdjustment: (0x1456, 1)> Output11OffDelay = <IntelligentTerminalFunctions.Output11OffDelay: (0x1487, 1)> Output11OnDelay = <IntelligentTerminalFunctions.Output11OnDelay: (0x1486, 1)> Output12OffDelay = <IntelligentTerminalFunctions.Output12OffDelay: (0x1489, 1)> Output12OnDelay = <IntelligentTerminalFunctions.Output12OnDelay: (0x1488, 1)> OverloadWarningLevel = <IntelligentTerminalFunctions.OverloadWarningLevel: (0x1429, 1)> OverloadWarningLevel2 = <IntelligentTerminalFunctions.OverloadWarningLevel2: (0x1473, 1)> OverloadWarningSignalOutputMode = <IntelligentTerminalFunctions.OverloadWarningSignalOutputMode: (0x1428, 1)> PIDDeviationExcessiveLevel = <IntelligentTerminalFunctions.PIDDeviationExcessiveLevel: (0x142e, 1)> PIDFeedbackLowerLimit = <IntelligentTerminalFunctions.PIDFeedbackLowerLimit: (0x1439, 1)> PIDFeedbackUpperLimit = <IntelligentTerminalFunctions.PIDFeedbackUpperLimit: (0x1438, 1)> RelayOutputFunction = <IntelligentTerminalFunctions.RelayOutputFunction: (0x141a, 1)> RelayOutputOffDelay = <IntelligentTerminalFunctions.RelayOutputOffDelay: (0x1491, 1)> RelayOutputOnDelay = <IntelligentTerminalFunctions.RelayOutputOnDelay: (0x1490, 1)> RelayOutputType = <IntelligentTerminalFunctions.RelayOutputType: (0x1424, 1)> ResetButtonSetting = <IntelligentTerminalFunctions.ResetButtonSetting: (0x146a, 1)> RestartFrequencyMatchingSelection = <IntelligentTerminalFunctions.RestartFrequencyMatchingSelection: (0x146b, 1)> ReversePowerRunningOvertorqueLevel = <IntelligentTerminalFunctions.ReversePowerRunningOvertorqueLevel: (0x143d, 1)> ReverseRegenerationOvertorqueLevel = <IntelligentTerminalFunctions.ReverseRegenerationOvertorqueLevel: (0x143c, 1)> TargetFrequencyDuringAcceleration = <IntelligentTerminalFunctions.TargetFrequencyDuringAcceleration: (0x142a, 2)> TargetFrequencyDuringAcceleration2 = <IntelligentTerminalFunctions.TargetFrequencyDuringAcceleration2: (0x142f, 2)> TargetFrequencyDuringDeceleration = <IntelligentTerminalFunctions.TargetFrequencyDuringDeceleration: (0x142c, 2)> TargetFrequencyDuringDeceleration2 = <IntelligentTerminalFunctions.TargetFrequencyDuringDeceleration2: (0x1431, 2)> ThermalWarningLevel = <IntelligentTerminalFunctions.ThermalWarningLevel: (0x1441, 1)> ThermistorAdjustment = <IntelligentTerminalFunctions.ThermistorAdjustment: (0x1459, 1)> TorqueModeSelection = <IntelligentTerminalFunctions.TorqueModeSelection: (0x143a, 1)> TorqueSignalOutputMode = <IntelligentTerminalFunctions.TorqueSignalOutputMode: (0x143f, 1)> UpDownButtonClearMode = <IntelligentTerminalFunctions.UpDownButtonClearMode: (0x146c, 1)> UpDownButtonSetting = <IntelligentTerminalFunctions.UpDownButtonSetting: (0x1469, 1)> ZeroHzDetectionLevel = <IntelligentTerminalFunctions.ZeroHzDetectionLevel: (0x1443, 1)> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
GroupD = class MonitoringFunctions(Register)
`` | `GroupD(value, names=None, *, module=None, qualname=None, type=None, start=1) Intelligent terminal function group. See datasheet sections 3-3 (pp. 74-88) and B-4 (pp. 319-320 and 322-323).`
| Method resolution order: MonitoringFunctions Register enum.Enum builtins.object Data and other attributes defined here: AnalogInputO = <MonitoringFunctions.AnalogInputO: (0x10a1, 1)> AnalogInputOI = <MonitoringFunctions.AnalogInputOI: (0x10a2, 1)> ConvertedOutputFrequency = <MonitoringFunctions.ConvertedOutputFrequency: (0x1009, 2)> CurrentPosition = <MonitoringFunctions.CurrentPosition: (0x1038, 2)> DCVoltage = <MonitoringFunctions.DCVoltage: (0x1026, 1)> DriveProgramming0 = <MonitoringFunctions.DriveProgramming0: (0x102e, 2)> DriveProgramming1 = <MonitoringFunctions.DriveProgramming1: (0x1030, 2)> DriveProgramming2 = <MonitoringFunctions.DriveProgramming2: (0x1032, 2)> ElectronicThermalMonitor = <MonitoringFunctions.ElectronicThermalMonitor: (0x1028, 1)> FaultFrequencyMonitor = <MonitoringFunctions.FaultFrequencyMonitor: (0x11, 1)> FaultMonitor1 = <MonitoringFunctions.FaultMonitor1: (0x12, 1)> FaultMonitor1Current = <MonitoringFunctions.FaultMonitor1Current: (0x16, 1)> FaultMonitor1Frequency = <MonitoringFunctions.FaultMonitor1Frequency: (0x14, 2)> FaultMonitor1InverterStatus = <MonitoringFunctions.FaultMonitor1InverterStatus: (0x13, 1)> FaultMonitor1PowerOnTime = <MonitoringFunctions.FaultMonitor1PowerOnTime: (0x1a, 2)> FaultMonitor1RunningTime = <MonitoringFunctions.FaultMonitor1RunningTime: (0x18, 2)> FaultMonitor1Voltage = <MonitoringFunctions.FaultMonitor1Voltage: (0x17, 1)> FaultMonitor2 = <MonitoringFunctions.FaultMonitor2: (0x1c, 1)> FaultMonitor2Current = <MonitoringFunctions.FaultMonitor2Current: (0x20, 1)> FaultMonitor2Frequency = <MonitoringFunctions.FaultMonitor2Frequency: (0x1e, 2)> FaultMonitor2InverterStatus = <MonitoringFunctions.FaultMonitor2InverterStatus: (0x1d, 1)> FaultMonitor2PowerOnTime = <MonitoringFunctions.FaultMonitor2PowerOnTime: (0x24, 2)> FaultMonitor2RunningTime = <MonitoringFunctions.FaultMonitor2RunningTime: (0x22, 2)> FaultMonitor2Voltage = <MonitoringFunctions.FaultMonitor2Voltage: (0x21, 1)> FaultMonitor3 = <MonitoringFunctions.FaultMonitor3: (0x26, 1)> FaultMonitor3Current = <MonitoringFunctions.FaultMonitor3Current: (0x2a, 1)> FaultMonitor3Frequency = <MonitoringFunctions.FaultMonitor3Frequency: (0x28, 2)> FaultMonitor3InverterStatus = <MonitoringFunctions.FaultMonitor3InverterStatus: (0x27, 1)> FaultMonitor3PowerOnTime = <MonitoringFunctions.FaultMonitor3PowerOnTime: (0x2e, 2)> FaultMonitor3RunningTime = <MonitoringFunctions.FaultMonitor3RunningTime: (0x2c, 2)> FaultMonitor3Voltage = <MonitoringFunctions.FaultMonitor3Voltage: (0x2b, 1)> FaultMonitor4 = <MonitoringFunctions.FaultMonitor4: (0x30, 1)> FaultMonitor4Current = <MonitoringFunctions.FaultMonitor4Current: (0x34, 1)> FaultMonitor4Frequency = <MonitoringFunctions.FaultMonitor4Frequency: (0x32, 2)> FaultMonitor4InverterStatus = <MonitoringFunctions.FaultMonitor4InverterStatus: (0x31, 1)> FaultMonitor4PowerOnTime = <MonitoringFunctions.FaultMonitor4PowerOnTime: (0x38, 2)> FaultMonitor4RunningTime = <MonitoringFunctions.FaultMonitor4RunningTime: (0x36, 2)> FaultMonitor4Voltage = <MonitoringFunctions.FaultMonitor4Voltage: (0x35, 1)> FaultMonitor5 = <MonitoringFunctions.FaultMonitor5: (0x3a, 1)> FaultMonitor5Current = <MonitoringFunctions.FaultMonitor5Current: (0x3e, 1)> FaultMonitor5Frequency = <MonitoringFunctions.FaultMonitor5Frequency: (0x3c, 2)> FaultMonitor5InverterStatus = <MonitoringFunctions.FaultMonitor5InverterStatus: (0x3b, 1)> FaultMonitor5PowerOnTime = <MonitoringFunctions.FaultMonitor5PowerOnTime: (0x42, 2)> FaultMonitor5RunningTime = <MonitoringFunctions.FaultMonitor5RunningTime: (0x40, 2)> FaultMonitor5Voltage = <MonitoringFunctions.FaultMonitor5Voltage: (0x3f, 1)> FaultMonitor6 = <MonitoringFunctions.FaultMonitor6: (0x44, 1)> FaultMonitor6Current = <MonitoringFunctions.FaultMonitor6Current: (0x48, 1)> FaultMonitor6Frequency = <MonitoringFunctions.FaultMonitor6Frequency: (0x46, 2)> FaultMonitor6InverterStatus = <MonitoringFunctions.FaultMonitor6InverterStatus: (0x45, 1)> FaultMonitor6PowerOnTime = <MonitoringFunctions.FaultMonitor6PowerOnTime: (0x4c, 2)> FaultMonitor6RunningTime = <MonitoringFunctions.FaultMonitor6RunningTime: (0x4a, 2)> FaultMonitor6Voltage = <MonitoringFunctions.FaultMonitor6Voltage: (0x49, 1)> FinTemperature = <MonitoringFunctions.FinTemperature: (0x1019, 1)> FrequencySource = <MonitoringFunctions.FrequencySource: (0x1059, 1)> InputPower = <MonitoringFunctions.InputPower: (0x1012, 1)> InverterMode = <MonitoringFunctions.InverterMode: (0x1057, 1)> LifeAssessment = <MonitoringFunctions.LifeAssessment: (0x101d, 1)> MultiFunctionInputs = <MonitoringFunctions.MultiFunctionInputs: (0x1007, 1)> MultiFunctionOutputs = <MonitoringFunctions.MultiFunctionOutputs: (0x1008, 1)> OutputCurrent = <MonitoringFunctions.OutputCurrent: (0x1003, 1)> OutputFrequency = <MonitoringFunctions.OutputFrequency: (0x1001, 2)> OutputTorque = <MonitoringFunctions.OutputTorque: (0x1010, 1)> OutputVoltage = <MonitoringFunctions.OutputVoltage: (0x1011, 1)> PIDDeviation = <MonitoringFunctions.PIDDeviation: (0x10a6, 1)> PIDFeedbackValue = <MonitoringFunctions.PIDFeedbackValue: (0x1005, 2)> PIDOutput = <MonitoringFunctions.PIDOutput: (0x10a8, 1)> PositionCommand = <MonitoringFunctions.PositionCommand: (0x1036, 2)> PowerOnTime = <MonitoringFunctions.PowerOnTime: (0x1017, 2)> ProgramCounter = <MonitoringFunctions.ProgramCounter: (0x101e, 1)> ProgramNumber = <MonitoringFunctions.ProgramNumber: (0x101f, 1)> PulseTrainInput = <MonitoringFunctions.PulseTrainInput: (0x10a4, 1)> RealFrequency = <MonitoringFunctions.RealFrequency: (0x100b, 2)> RegenerativeBrakingLoadRate = <MonitoringFunctions.RegenerativeBrakingLoadRate: (0x1027, 1)> RotationDirection = <MonitoringFunctions.RotationDirection: (0x1004, 1)> RunSource = <MonitoringFunctions.RunSource: (0x105a, 1)> TorqueBias = <MonitoringFunctions.TorqueBias: (0x100e, 1)> TorqueReference = <MonitoringFunctions.TorqueReference: (0x100d, 1)> TotalRunTime = <MonitoringFunctions.TotalRunTime: (0x1015, 2)> WarningMonitor = <MonitoringFunctions.WarningMonitor: (0x4e, 1)> WattHour = <MonitoringFunctions.WattHour: (0x1013, 2)> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
GroupF = class MainProfileParameters(Register)
`` | `GroupF(value, names=None, *, module=None, qualname=None, type=None, start=1) Main profile parameters group. See datasheet sections 3-4 (p. 89) and B-4 (pp. 319-320, 322-323 and 344).`
| Method resolution order: MainProfileParameters Register enum.Enum builtins.object Data and other attributes defined here: AccelerationTime1 = <MainProfileParameters.AccelerationTime1: (0x1103, 2)> DecelerationTime1 = <MainProfileParameters.DecelerationTime1: (0x1105, 2)> OperatorRotationDirection = <MainProfileParameters.OperatorRotationDirection: (0x1107, 1)> OutputFrequency = <MainProfileParameters.OutputFrequency: (0x01, 2)> SecondAccelerationTime1 = <MainProfileParameters.SecondAccelerationTime1: (0x2103, 2)> SecondDecelerationTime1 = <MainProfileParameters.SecondDecelerationTime1: (0x2105, 2)> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
GroupH = class MotorConstantsFunctions(Register)
`` | `GroupH(value, names=None, *, module=None, qualname=None, type=None, start=1) Motor constants function group. See datasheet sections 3-8 (pp. 172-178) and B-4 (pp. 337-338).`
| Method resolution order: MotorConstantsFunctions Register enum.Enum builtins.object Data and other attributes defined here: AutoTuningPMParameterLd = <MotorConstantsFunctions.AutoTuningPMParameterLd: (0x157c, 1)> AutoTuningPMParameterLq = <MotorConstantsFunctions.AutoTuningPMParameterLq: (0x157d, 1)> AutoTuningPMParameterR = <MotorConstantsFunctions.AutoTuningPMParameterR: (0x157b, 1)> AutoTuningParameterIo = <MotorConstantsFunctions.AutoTuningParameterIo: (0x152b, 1)> AutoTuningParameterJ = <MotorConstantsFunctions.AutoTuningParameterJ: (0x152c, 2)> AutoTuningParameterR1 = <MotorConstantsFunctions.AutoTuningParameterR1: (0x1525, 1)> AutoTuningParameterR2 = <MotorConstantsFunctions.AutoTuningParameterR2: (0x1527, 1)> AutoTuningSelection = <MotorConstantsFunctions.AutoTuningSelection: (0x1501, 1)> H022 = <MotorConstantsFunctions.H022: (0x151a, 1)> H032 = <MotorConstantsFunctions.H032: (0x1529, 1)> MotorCapacitySelection = <MotorConstantsFunctions.MotorCapacitySelection: (0x1503, 1)> MotorParameterIo = <MotorConstantsFunctions.MotorParameterIo: (0x151c, 1)> MotorParameterJ = <MotorConstantsFunctions.MotorParameterJ: (0x151d, 2)> MotorParameterR1 = <MotorConstantsFunctions.MotorParameterR1: (0x1516, 1)> MotorParameterR2 = <MotorConstantsFunctions.MotorParameterR2: (0x1518, 1)> MotorParameterSelection = <MotorConstantsFunctions.MotorParameterSelection: (0x1502, 1)> MotorPoleNumberSelection = <MotorConstantsFunctions.MotorPoleNumberSelection: (0x1504, 1)> PMIMPE0VWait = <MotorConstantsFunctions.PMIMPE0VWait: (0x158a, 1)> PMIMPEDetect = <MotorConstantsFunctions.PMIMPEDetect: (0x158c, 1)> PMIMPEDetectWait = <MotorConstantsFunctions.PMIMPEDetectWait: (0x158b, 1)> PMIMPEVoltageGain = <MotorConstantsFunctions.PMIMPEVoltageGain: (0x158d, 1)> PMMinimumFrequency = <MotorConstantsFunctions.PMMinimumFrequency: (0x1586, 1)> PMMotorCapacity = <MotorConstantsFunctions.PMMotorCapacity: (0x1572, 1)> PMMotorCodeSelection = <MotorConstantsFunctions.PMMotorCodeSelection: (0x1571, 1)> PMMotorPoleNumberSelection = <MotorConstantsFunctions.PMMotorPoleNumberSelection: (0x1573, 1)> PMNoLoadCurrent = <MotorConstantsFunctions.PMNoLoadCurrent: (0x1587, 1)> PMParameterJ = <MotorConstantsFunctions.PMParameterJ: (0x1579, 2)> PMParameterKe = <MotorConstantsFunctions.PMParameterKe: (0x1578, 1)> PMParameterLd = <MotorConstantsFunctions.PMParameterLd: (0x1576, 1)> PMParameterLq = <MotorConstantsFunctions.PMParameterLq: (0x1577, 1)> PMParameterR = <MotorConstantsFunctions.PMParameterR: (0x1575, 1)> PMRatedCurrent = <MotorConstantsFunctions.PMRatedCurrent: (0x1574, 1)> PMSpeedResponse = <MotorConstantsFunctions.PMSpeedResponse: (0x1581, 1)> PMStabilizationConstant = <MotorConstantsFunctions.PMStabilizationConstant: (0x1584, 1)> PMStartingCurrent = <MotorConstantsFunctions.PMStartingCurrent: (0x1582, 1)> PMStartingMethod = <MotorConstantsFunctions.PMStartingMethod: (0x1588, 1)> PMStartingTime = <MotorConstantsFunctions.PMStartingTime: (0x1583, 1)> SlipCompensationIGain = <MotorConstantsFunctions.SlipCompensationIGain: (0x153e, 1)> SlipCompensationPGain = <MotorConstantsFunctions.SlipCompensationPGain: (0x153d, 1)> SpeedResponse = <MotorConstantsFunctions.SpeedResponse: (0x1506, 1)> StabilizationParameter = <MotorConstantsFunctions.StabilizationParameter: (0x1507, 1)> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
GroupP = class OtherParameters(Register)
`` | `GroupP(value, names=None, *, module=None, qualname=None, type=None, start=1) Other parameters group. See datasheet sections 3-9 (pp. 179-190) and B-4 (pp. 339-343).`
| Method resolution order: OtherParameters Register enum.Enum builtins.object Data and other attributes defined here: AccelerationDecelerationTimeInputType = <OtherParameters.AccelerationDecelerationTimeInputType: (0x161f, 1)> CANOpenCommunicationSpeed = <OtherParameters.CANOpenCommunicationSpeed: (0x16bc, 1)> CANOpenNodeAddress = <OtherParameters.CANOpenNodeAddress: (0x16bb, 1)> CommunicationErrorEffect = <OtherParameters.CommunicationErrorEffect: (0x162f, 1)> CompoNetNodeAddress = <OtherParameters.CompoNetNodeAddress: (0x16c0, 1)> CreepSpeed = <OtherParameters.CreepSpeed: (0x160f, 1)> CurrentPositionAtPowerOff = <OtherParameters.CurrentPositionAtPowerOff: (0x165e, 1)> DeviceNetNodeAddress = <OtherParameters.DeviceNetNodeAddress: (0x16c2, 1)> DriveProgramParameterU00 = <OtherParameters.DriveProgramParameterU00: (0x1666, 1)> DriveProgramParameterU01 = <OtherParameters.DriveProgramParameterU01: (0x1667, 1)> DriveProgramParameterU02 = <OtherParameters.DriveProgramParameterU02: (0x1668, 1)> DriveProgramParameterU03 = <OtherParameters.DriveProgramParameterU03: (0x1669, 1)> DriveProgramParameterU04 = <OtherParameters.DriveProgramParameterU04: (0x166a, 1)> DriveProgramParameterU05 = <OtherParameters.DriveProgramParameterU05: (0x166b, 1)> DriveProgramParameterU06 = <OtherParameters.DriveProgramParameterU06: (0x166c, 1)> DriveProgramParameterU07 = <OtherParameters.DriveProgramParameterU07: (0x166d, 1)> DriveProgramParameterU08 = <OtherParameters.DriveProgramParameterU08: (0x166e, 1)> DriveProgramParameterU09 = <OtherParameters.DriveProgramParameterU09: (0x166f, 1)> DriveProgramParameterU10 = <OtherParameters.DriveProgramParameterU10: (0x1670, 1)> DriveProgramParameterU11 = <OtherParameters.DriveProgramParameterU11: (0x1671, 1)> DriveProgramParameterU12 = <OtherParameters.DriveProgramParameterU12: (0x1672, 1)> DriveProgramParameterU13 = <OtherParameters.DriveProgramParameterU13: (0x1673, 1)> DriveProgramParameterU14 = <OtherParameters.DriveProgramParameterU14: (0x1674, 1)> DriveProgramParameterU15 = <OtherParameters.DriveProgramParameterU15: (0x1675, 1)> DriveProgramParameterU16 = <OtherParameters.DriveProgramParameterU16: (0x1676, 1)> DriveProgramParameterU17 = <OtherParameters.DriveProgramParameterU17: (0x1677, 1)> DriveProgramParameterU18 = <OtherParameters.DriveProgramParameterU18: (0x1678, 1)> DriveProgramParameterU19 = <OtherParameters.DriveProgramParameterU19: (0x1679, 1)> DriveProgramParameterU20 = <OtherParameters.DriveProgramParameterU20: (0x167a, 1)> DriveProgramParameterU21 = <OtherParameters.DriveProgramParameterU21: (0x167b, 1)> DriveProgramParameterU22 = <OtherParameters.DriveProgramParameterU22: (0x167c, 1)> DriveProgramParameterU23 = <OtherParameters.DriveProgramParameterU23: (0x167d, 1)> DriveProgramParameterU24 = <OtherParameters.DriveProgramParameterU24: (0x167e, 1)> DriveProgramParameterU25 = <OtherParameters.DriveProgramParameterU25: (0x167f, 1)> DriveProgramParameterU26 = <OtherParameters.DriveProgramParameterU26: (0x1680, 1)> DriveProgramParameterU27 = <OtherParameters.DriveProgramParameterU27: (0x1681, 1)> DriveProgramParameterU28 = <OtherParameters.DriveProgramParameterU28: (0x1682, 1)> DriveProgramParameterU29 = <OtherParameters.DriveProgramParameterU29: (0x1683, 1)> DriveProgramParameterU30 = <OtherParameters.DriveProgramParameterU30: (0x1684, 1)> DriveProgramParameterU31 = <OtherParameters.DriveProgramParameterU31: (0x1685, 1)> EATerminalFunction = <OtherParameters.EATerminalFunction: (0x1603, 1)> EZCOMMDestination1Address = <OtherParameters.EZCOMMDestination1Address: (0x168f, 1)> EZCOMMDestination1Register = <OtherParameters.EZCOMMDestination1Register: (0x1690, 1)> EZCOMMDestination2Address = <OtherParameters.EZCOMMDestination2Address: (0x1692, 1)> EZCOMMDestination2Register = <OtherParameters.EZCOMMDestination2Register: (0x1693, 1)> EZCOMMDestination3Address = <OtherParameters.EZCOMMDestination3Address: (0x1695, 1)> EZCOMMDestination3Register = <OtherParameters.EZCOMMDestination3Register: (0x1696, 1)> EZCOMMDestination4Address = <OtherParameters.EZCOMMDestination4Address: (0x1698, 1)> EZCOMMDestination4Register = <OtherParameters.EZCOMMDestination4Register: (0x1699, 1)> EZCOMMDestination5Address = <OtherParameters.EZCOMMDestination5Address: (0x169b, 1)> EZCOMMDestination5Register = <OtherParameters.EZCOMMDestination5Register: (0x169c, 1)> EZCOMMSource1Register = <OtherParameters.EZCOMMSource1Register: (0x1691, 1)> EZCOMMSource2Register = <OtherParameters.EZCOMMSource2Register: (0x1694, 1)> EZCOMMSource3Register = <OtherParameters.EZCOMMSource3Register: (0x1697, 1)> EZCOMMSource4Register = <OtherParameters.EZCOMMSource4Register: (0x169a, 1)> EZCOMMSource5Register = <OtherParameters.EZCOMMSource5Register: (0x169d, 1)> EncoderDisconnectionTimeout = <OtherParameters.EncoderDisconnectionTimeout: (0x1659, 1)> EncoderPulses = <OtherParameters.EncoderPulses: (0x160b, 1)> Endianness = <OtherParameters.Endianness: (0x16f1, 1)> EzCOMMDataCount = <OtherParameters.EzCOMMDataCount: (0x168e, 1)> ForwardPositionRangeSpecification = <OtherParameters.ForwardPositionRangeSpecification: (0x1652, 2)> ForwardTorqueControlSpeedLimitValue = <OtherParameters.ForwardTorqueControlSpeedLimitValue: (0x1627, 2)> HighSpeedZeroReturnFrequency = <OtherParameters.HighSpeedZeroReturnFrequency: (0x1651, 1)> InstanceNumber = <OtherParameters.InstanceNumber: (0x1630, 1)> LowSpeedZeroReturnFrequency = <OtherParameters.LowSpeedZeroReturnFrequency: (0x1650, 1)> ModbusExternalRegister1 = <OtherParameters.ModbusExternalRegister1: (0x16c9, 1)> ModbusExternalRegister10 = <OtherParameters.ModbusExternalRegister10: (0x16d2, 1)> ModbusExternalRegister2 = <OtherParameters.ModbusExternalRegister2: (0x16ca, 1)> ModbusExternalRegister3 = <OtherParameters.ModbusExternalRegister3: (0x16cb, 1)> ModbusExternalRegister4 = <OtherParameters.ModbusExternalRegister4: (0x16cc, 1)> ModbusExternalRegister5 = <OtherParameters.ModbusExternalRegister5: (0x16cd, 1)> ModbusExternalRegister6 = <OtherParameters.ModbusExternalRegister6: (0x16ce, 1)> ModbusExternalRegister7 = <OtherParameters.ModbusExternalRegister7: (0x16cf, 1)> ModbusExternalRegister8 = <OtherParameters.ModbusExternalRegister8: (0x16d0, 1)> ModbusExternalRegister9 = <OtherParameters.ModbusExternalRegister9: (0x16d1, 1)> ModbusInternalRegister1 = <OtherParameters.ModbusInternalRegister1: (0x16e7, 1)> ModbusInternalRegister10 = <OtherParameters.ModbusInternalRegister10: (0x16f0, 1)> ModbusInternalRegister2 = <OtherParameters.ModbusInternalRegister2: (0x16e8, 1)> ModbusInternalRegister3 = <OtherParameters.ModbusInternalRegister3: (0x16e9, 1)> ModbusInternalRegister4 = <OtherParameters.ModbusInternalRegister4: (0x16ea, 1)> ModbusInternalRegister5 = <OtherParameters.ModbusInternalRegister5: (0x16eb, 1)> ModbusInternalRegister6 = <OtherParameters.ModbusInternalRegister6: (0x16ec, 1)> ModbusInternalRegister7 = <OtherParameters.ModbusInternalRegister7: (0x16ed, 1)> ModbusInternalRegister8 = <OtherParameters.ModbusInternalRegister8: (0x16ee, 1)> ModbusInternalRegister9 = <OtherParameters.ModbusInternalRegister9: (0x16ef, 1)> ModbusRegisterFormat1 = <OtherParameters.ModbusRegisterFormat1: (0x16d3, 1)> ModbusRegisterFormat10 = <OtherParameters.ModbusRegisterFormat10: (0x16dc, 1)> ModbusRegisterFormat2 = <OtherParameters.ModbusRegisterFormat2: (0x16d4, 1)> ModbusRegisterFormat3 = <OtherParameters.ModbusRegisterFormat3: (0x16d5, 1)> ModbusRegisterFormat4 = <OtherParameters.ModbusRegisterFormat4: (0x16d6, 1)> ModbusRegisterFormat5 = <OtherParameters.ModbusRegisterFormat5: (0x16d7, 1)> ModbusRegisterFormat6 = <OtherParameters.ModbusRegisterFormat6: (0x16d8, 1)> ModbusRegisterFormat7 = <OtherParameters.ModbusRegisterFormat7: (0x16d9, 1)> ModbusRegisterFormat8 = <OtherParameters.ModbusRegisterFormat8: (0x16da, 1)> ModbusRegisterFormat9 = <OtherParameters.ModbusRegisterFormat9: (0x16db, 1)> ModbusRegisterScaling1 = <OtherParameters.ModbusRegisterScaling1: (0x16dd, 1)> ModbusRegisterScaling10 = <OtherParameters.ModbusRegisterScaling10: (0x16e6, 1)> ModbusRegisterScaling2 = <OtherParameters.ModbusRegisterScaling2: (0x16de, 1)> ModbusRegisterScaling3 = <OtherParameters.ModbusRegisterScaling3: (0x16df, 1)> ModbusRegisterScaling4 = <OtherParameters.ModbusRegisterScaling4: (0x16e0, 1)> ModbusRegisterScaling5 = <OtherParameters.ModbusRegisterScaling5: (0x16e1, 1)> ModbusRegisterScaling6 = <OtherParameters.ModbusRegisterScaling6: (0x16e2, 1)> ModbusRegisterScaling7 = <OtherParameters.ModbusRegisterScaling7: (0x16e3, 1)> ModbusRegisterScaling8 = <OtherParameters.ModbusRegisterScaling8: (0x16e4, 1)> ModbusRegisterScaling9 = <OtherParameters.ModbusRegisterScaling9: (0x16e5, 1)> MultiStepPositionCommand0 = <OtherParameters.MultiStepPositionCommand0: (0x163e, 2)> MultiStepPositionCommand1 = <OtherParameters.MultiStepPositionCommand1: (0x1640, 2)> MultiStepPositionCommand2 = <OtherParameters.MultiStepPositionCommand2: (0x1642, 2)> MultiStepPositionCommand3 = <OtherParameters.MultiStepPositionCommand3: (0x1644, 2)> MultiStepPositionCommand4 = <OtherParameters.MultiStepPositionCommand4: (0x1646, 2)> MultiStepPositionCommand5 = <OtherParameters.MultiStepPositionCommand5: (0x1648, 2)> MultiStepPositionCommand6 = <OtherParameters.MultiStepPositionCommand6: (0x164a, 2)> MultiStepPositionCommand7 = <OtherParameters.MultiStepPositionCommand7: (0x164c, 2)> NetworkCommunicationWatchdogTimer = <OtherParameters.NetworkCommunicationWatchdogTimer: (0x162e, 1)> OperationSelectionAtOption1Error = <OtherParameters.OperationSelectionAtOption1Error: (0x1601, 1)> OperationSettingInIdleMode = <OtherParameters.OperationSettingInIdleMode: (0x1632, 1)> OptionIFCommandReadRegister1 = <OtherParameters.OptionIFCommandReadRegister1: (0x16ac, 1)> OptionIFCommandReadRegister10 = <OtherParameters.OptionIFCommandReadRegister10: (0x16b5, 1)> OptionIFCommandReadRegister2 = <OtherParameters.OptionIFCommandReadRegister2: (0x16ad, 1)> OptionIFCommandReadRegister3 = <OtherParameters.OptionIFCommandReadRegister3: (0x16ae, 1)> OptionIFCommandReadRegister4 = <OtherParameters.OptionIFCommandReadRegister4: (0x16af, 1)> OptionIFCommandReadRegister5 = <OtherParameters.OptionIFCommandReadRegister5: (0x16b0, 1)> OptionIFCommandReadRegister6 = <OtherParameters.OptionIFCommandReadRegister6: (0x16b1, 1)> OptionIFCommandReadRegister7 = <OtherParameters.OptionIFCommandReadRegister7: (0x16b2, 1)> OptionIFCommandReadRegister8 = <OtherParameters.OptionIFCommandReadRegister8: (0x16b3, 1)> OptionIFCommandReadRegister9 = <OtherParameters.OptionIFCommandReadRegister9: (0x16b4, 1)> OptionIFCommandWriteRegister1 = <OtherParameters.OptionIFCommandWriteRegister1: (0x16a2, 1)> OptionIFCommandWriteRegister10 = <OtherParameters.OptionIFCommandWriteRegister10: (0x16ab, 1)> OptionIFCommandWriteRegister2 = <OtherParameters.OptionIFCommandWriteRegister2: (0x16a3, 1)> OptionIFCommandWriteRegister3 = <OtherParameters.OptionIFCommandWriteRegister3: (0x16a4, 1)> OptionIFCommandWriteRegister4 = <OtherParameters.OptionIFCommandWriteRegister4: (0x16a5, 1)> OptionIFCommandWriteRegister5 = <OtherParameters.OptionIFCommandWriteRegister5: (0x16a6, 1)> OptionIFCommandWriteRegister6 = <OtherParameters.OptionIFCommandWriteRegister6: (0x16a7, 1)> OptionIFCommandWriteRegister7 = <OtherParameters.OptionIFCommandWriteRegister7: (0x16a8, 1)> OptionIFCommandWriteRegister8 = <OtherParameters.OptionIFCommandWriteRegister8: (0x16a9, 1)> OptionIFCommandWriteRegister9 = <OtherParameters.OptionIFCommandWriteRegister9: (0x16aa, 1)> OverSpeedErrorDetectionLevel = <OtherParameters.OverSpeedErrorDetectionLevel: (0x161a, 1)> PolaritySettingForRotationSpeed = <OtherParameters.PolaritySettingForRotationSpeed: (0x1633, 1)> PositionRestartRange = <OtherParameters.PositionRestartRange: (0x165c, 1)> PositioningMode = <OtherParameters.PositioningMode: (0x1657, 1)> PositioningRange = <OtherParameters.PositioningRange: (0x1611, 1)> PresetPosition = <OtherParameters.PresetPosition: (0x1660, 1)> ProfibusClearMode = <OtherParameters.ProfibusClearMode: (0x16b7, 1)> ProfibusMapSelection = <OtherParameters.ProfibusMapSelection: (0x16b8, 1)> ProfibusNodeAddress = <OtherParameters.ProfibusNodeAddress: (0x16b6, 1)> PulseInputLowerCut = <OtherParameters.PulseInputLowerCut: (0x163d, 1)> PulseTrainFrequencyBiasAmount = <OtherParameters.PulseTrainFrequencyBiasAmount: (0x163b, 1)> PulseTrainFrequencyFilterTimeConstant = <OtherParameters.PulseTrainFrequencyFilterTimeConstant: (0x163a, 1)> PulseTrainFrequencyLimit = <OtherParameters.PulseTrainFrequencyLimit: (0x163c, 1)> PulseTrainFrequencyScale = <OtherParameters.PulseTrainFrequencyScale: (0x1639, 1)> PulseTrainInputModeForFeedback = <OtherParameters.PulseTrainInputModeForFeedback: (0x1604, 1)> ReversePositionRangeSpecification = <OtherParameters.ReversePositionRangeSpecification: (0x1654, 2)> ReverseTorqueControlSpeedLimitValue = <OtherParameters.ReverseTorqueControlSpeedLimitValue: (0x1629, 2)> SavePositionAtPowerOff = <OtherParameters.SavePositionAtPowerOff: (0x165d, 1)> SerialCommunicationMode = <OtherParameters.SerialCommunicationMode: (0x16c8, 1)> SimplePositioning = <OtherParameters.SimplePositioning: (0x160c, 1)> SpeedDeviationErrorDetectionLevel = <OtherParameters.SpeedDeviationErrorDetectionLevel: (0x161b, 1)> SpeedTorqueControlSwitchingTime = <OtherParameters.SpeedTorqueControlSwitchingTime: (0x162b, 1)> TorqueBiasMode = <OtherParameters.TorqueBiasMode: (0x1624, 1)> TorqueBiasPolaritySelection = <OtherParameters.TorqueBiasPolaritySelection: (0x1626, 1)> TorqueBiasValue = <OtherParameters.TorqueBiasValue: (0x1625, 1)> TorqueReferenceInputSelection = <OtherParameters.TorqueReferenceInputSelection: (0x1621, 1)> TorqueReferenceSetting = <OtherParameters.TorqueReferenceSetting: (0x1622, 1)> ZeroReturnDirection = <OtherParameters.ZeroReturnDirection: (0x164f, 1)> ZeroReturnMode = <OtherParameters.ZeroReturnMode: (0x164e, 1)> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
class IntelligentTerminalFunctions(Register)
`` | `IntelligentTerminalFunctions(value, names=None, *, module=None, qualname=None, type=None, start=1) Intelligent terminal function group. See datasheet sections 3-7 (pp. 153-171) and B-4 (pp. 332-336).`
| Method resolution order: IntelligentTerminalFunctions Register enum.Enum builtins.object Data and other attributes defined here: AMBias = <IntelligentTerminalFunctions.AMBias: (0x1471, 1)> AMGain = <IntelligentTerminalFunctions.AMGain: (0x146e, 1)> AMTerminalFunction = <IntelligentTerminalFunctions.AMTerminalFunction: (0x141c, 1)> BaudRate = <IntelligentTerminalFunctions.BaudRate: (0x144b, 1)> CommunicationErrorEffect = <IntelligentTerminalFunctions.CommunicationErrorEffect: (0x1450, 1)> CommunicationErrorTimeout = <IntelligentTerminalFunctions.CommunicationErrorTimeout: (0x1451, 1)> CommunicationParity = <IntelligentTerminalFunctions.CommunicationParity: (0x144e, 1)> CommunicationSelection = <IntelligentTerminalFunctions.CommunicationSelection: (0x1464, 1)> CommunicationStopBits = <IntelligentTerminalFunctions.CommunicationStopBits: (0x144f, 1)> CommunicationWaitTime = <IntelligentTerminalFunctions.CommunicationWaitTime: (0x1452, 1)> CurrentMonitorReferenceValue = <IntelligentTerminalFunctions.CurrentMonitorReferenceValue: (0x141e, 1)> DebugMode = <IntelligentTerminalFunctions.DebugMode: (0x145f, 1)> DeviceID = <IntelligentTerminalFunctions.DeviceID: (0x144c, 1)> EOGain = <IntelligentTerminalFunctions.EOGain: (0x146d, 1)> EOOutputPulseTrainScaleConversion = <IntelligentTerminalFunctions.EOOutputPulseTrainScaleConversion: (0x1433, 1)> EOTerminalFunction = <IntelligentTerminalFunctions.EOTerminalFunction: (0x141b, 1)> EzCOMMasterEndAddress = <IntelligentTerminalFunctions.EzCOMMasterEndAddress: (0x1467, 1)> EzCOMMasterStartAddress = <IntelligentTerminalFunctions.EzCOMMasterStartAddress: (0x1466, 1)> EzCOMStartingTrigger = <IntelligentTerminalFunctions.EzCOMStartingTrigger: (0x1468, 1)> FinOverheatWarningLevel = <IntelligentTerminalFunctions.FinOverheatWarningLevel: (0x1444, 1)> ForwardPowerRunningOvertorqueLevel = <IntelligentTerminalFunctions.ForwardPowerRunningOvertorqueLevel: (0x143b, 1)> ForwardRegenerationOvertorqueLevel = <IntelligentTerminalFunctions.ForwardRegenerationOvertorqueLevel: (0x143e, 1)> InputTerminalResponseTime1 = <IntelligentTerminalFunctions.InputTerminalResponseTime1: (0x14a4, 1)> InputTerminalResponseTime2 = <IntelligentTerminalFunctions.InputTerminalResponseTime2: (0x14a5, 1)> InputTerminalResponseTime3 = <IntelligentTerminalFunctions.InputTerminalResponseTime3: (0x14a6, 1)> InputTerminalResponseTime4 = <IntelligentTerminalFunctions.InputTerminalResponseTime4: (0x14a7, 1)> InputTerminalResponseTime5 = <IntelligentTerminalFunctions.InputTerminalResponseTime5: (0x14a8, 1)> InputTerminalResponseTime6 = <IntelligentTerminalFunctions.InputTerminalResponseTime6: (0x14a9, 1)> InputTerminalResponseTime7 = <IntelligentTerminalFunctions.InputTerminalResponseTime7: (0x14aa, 1)> LightLoadDetectionLevel = <IntelligentTerminalFunctions.LightLoadDetectionLevel: (0x1427, 1)> LightLoadSignalOutputMode = <IntelligentTerminalFunctions.LightLoadSignalOutputMode: (0x1426, 1)> LogicOutputSignal1OperatorSelection = <IntelligentTerminalFunctions.LogicOutputSignal1OperatorSelection: (0x1494, 1)> LogicOutputSignal1Selection1 = <IntelligentTerminalFunctions.LogicOutputSignal1Selection1: (0x1492, 1)> LogicOutputSignal1Selection2 = <IntelligentTerminalFunctions.LogicOutputSignal1Selection2: (0x1493, 1)> LogicOutputSignal2OperatorSelection = <IntelligentTerminalFunctions.LogicOutputSignal2OperatorSelection: (0x1497, 1)> LogicOutputSignal2Selection1 = <IntelligentTerminalFunctions.LogicOutputSignal2Selection1: (0x1495, 1)> LogicOutputSignal2Selection2 = <IntelligentTerminalFunctions.LogicOutputSignal2Selection2: (0x1496, 1)> LogicOutputSignal3OperatorSelection = <IntelligentTerminalFunctions.LogicOutputSignal3OperatorSelection: (0x149a, 1)> LogicOutputSignal3Selection1 = <IntelligentTerminalFunctions.LogicOutputSignal3Selection1: (0x1498, 1)> LogicOutputSignal3Selection2 = <IntelligentTerminalFunctions.LogicOutputSignal3Selection2: (0x1499, 1)> MultiFunctionInput1Function = <IntelligentTerminalFunctions.MultiFunctionInput1Function: (0x1401, 1)> MultiFunctionInput1Type = <IntelligentTerminalFunctions.MultiFunctionInput1Type: (0x140b, 1)> MultiFunctionInput2Function = <IntelligentTerminalFunctions.MultiFunctionInput2Function: (0x1402, 1)> MultiFunctionInput2Type = <IntelligentTerminalFunctions.MultiFunctionInput2Type: (0x140c, 1)> MultiFunctionInput3Function = <IntelligentTerminalFunctions.MultiFunctionInput3Function: (0x1403, 1)> MultiFunctionInput3Type = <IntelligentTerminalFunctions.MultiFunctionInput3Type: (0x140d, 1)> MultiFunctionInput4Function = <IntelligentTerminalFunctions.MultiFunctionInput4Function: (0x1404, 1)> MultiFunctionInput4Type = <IntelligentTerminalFunctions.MultiFunctionInput4Type: (0x140e, 1)> MultiFunctionInput5Function = <IntelligentTerminalFunctions.MultiFunctionInput5Function: (0x1405, 1)> MultiFunctionInput5Type = <IntelligentTerminalFunctions.MultiFunctionInput5Type: (0x140f, 1)> MultiFunctionInput6Function = <IntelligentTerminalFunctions.MultiFunctionInput6Function: (0x1406, 1)> MultiFunctionInput6Type = <IntelligentTerminalFunctions.MultiFunctionInput6Type: (0x1410, 1)> MultiFunctionInput7Function = <IntelligentTerminalFunctions.MultiFunctionInput7Function: (0x1407, 1)> MultiFunctionInput7Type = <IntelligentTerminalFunctions.MultiFunctionInput7Type: (0x1411, 1)> MultiFunctionOutput11Function = <IntelligentTerminalFunctions.MultiFunctionOutput11Function: (0x1415, 1)> MultiFunctionOutput11Type = <IntelligentTerminalFunctions.MultiFunctionOutput11Type: (0x141f, 1)> MultiFunctionOutput12Function = <IntelligentTerminalFunctions.MultiFunctionOutput12Function: (0x1416, 1)> MultiFunctionOutput12Type = <IntelligentTerminalFunctions.MultiFunctionOutput12Type: (0x1420, 1)> MultiStepSpeedPositionDeterminationTime = <IntelligentTerminalFunctions.MultiStepSpeedPositionDeterminationTime: (0x14ad, 1)> OAdjustment = <IntelligentTerminalFunctions.OAdjustment: (0x1455, 1)> OIAdjustment = <IntelligentTerminalFunctions.OIAdjustment: (0x1456, 1)> Output11OffDelay = <IntelligentTerminalFunctions.Output11OffDelay: (0x1487, 1)> Output11OnDelay = <IntelligentTerminalFunctions.Output11OnDelay: (0x1486, 1)> Output12OffDelay = <IntelligentTerminalFunctions.Output12OffDelay: (0x1489, 1)> Output12OnDelay = <IntelligentTerminalFunctions.Output12OnDelay: (0x1488, 1)> OverloadWarningLevel = <IntelligentTerminalFunctions.OverloadWarningLevel: (0x1429, 1)> OverloadWarningLevel2 = <IntelligentTerminalFunctions.OverloadWarningLevel2: (0x1473, 1)> OverloadWarningSignalOutputMode = <IntelligentTerminalFunctions.OverloadWarningSignalOutputMode: (0x1428, 1)> PIDDeviationExcessiveLevel = <IntelligentTerminalFunctions.PIDDeviationExcessiveLevel: (0x142e, 1)> PIDFeedbackLowerLimit = <IntelligentTerminalFunctions.PIDFeedbackLowerLimit: (0x1439, 1)> PIDFeedbackUpperLimit = <IntelligentTerminalFunctions.PIDFeedbackUpperLimit: (0x1438, 1)> RelayOutputFunction = <IntelligentTerminalFunctions.RelayOutputFunction: (0x141a, 1)> RelayOutputOffDelay = <IntelligentTerminalFunctions.RelayOutputOffDelay: (0x1491, 1)> RelayOutputOnDelay = <IntelligentTerminalFunctions.RelayOutputOnDelay: (0x1490, 1)> RelayOutputType = <IntelligentTerminalFunctions.RelayOutputType: (0x1424, 1)> ResetButtonSetting = <IntelligentTerminalFunctions.ResetButtonSetting: (0x146a, 1)> RestartFrequencyMatchingSelection = <IntelligentTerminalFunctions.RestartFrequencyMatchingSelection: (0x146b, 1)> ReversePowerRunningOvertorqueLevel = <IntelligentTerminalFunctions.ReversePowerRunningOvertorqueLevel: (0x143d, 1)> ReverseRegenerationOvertorqueLevel = <IntelligentTerminalFunctions.ReverseRegenerationOvertorqueLevel: (0x143c, 1)> TargetFrequencyDuringAcceleration = <IntelligentTerminalFunctions.TargetFrequencyDuringAcceleration: (0x142a, 2)> TargetFrequencyDuringAcceleration2 = <IntelligentTerminalFunctions.TargetFrequencyDuringAcceleration2: (0x142f, 2)> TargetFrequencyDuringDeceleration = <IntelligentTerminalFunctions.TargetFrequencyDuringDeceleration: (0x142c, 2)> TargetFrequencyDuringDeceleration2 = <IntelligentTerminalFunctions.TargetFrequencyDuringDeceleration2: (0x1431, 2)> ThermalWarningLevel = <IntelligentTerminalFunctions.ThermalWarningLevel: (0x1441, 1)> ThermistorAdjustment = <IntelligentTerminalFunctions.ThermistorAdjustment: (0x1459, 1)> TorqueModeSelection = <IntelligentTerminalFunctions.TorqueModeSelection: (0x143a, 1)> TorqueSignalOutputMode = <IntelligentTerminalFunctions.TorqueSignalOutputMode: (0x143f, 1)> UpDownButtonClearMode = <IntelligentTerminalFunctions.UpDownButtonClearMode: (0x146c, 1)> UpDownButtonSetting = <IntelligentTerminalFunctions.UpDownButtonSetting: (0x1469, 1)> ZeroHzDetectionLevel = <IntelligentTerminalFunctions.ZeroHzDetectionLevel: (0x1443, 1)> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
class InverterStatus(enum.IntEnum)
`` | `InverterStatus(value, names=None, *, module=None, qualname=None, type=None, start=1) Codes identifying the status of the inverter (datasheet section B-4 p. 421).`
| Method resolution order: InverterStatus enum.IntEnum builtins.int enum.Enum builtins.object Data and other attributes defined here: Accelerating = <InverterStatus.Accelerating: 4> ConstantSpeedOperation = <InverterStatus.ConstantSpeedOperation: 3> DCBreaking = <InverterStatus.DCBreaking: 7> Decelerating = <InverterStatus.Decelerating: 2> OperatingAtZeroFrequency = <InverterStatus.OperatingAtZeroFrequency: 5> OverloadRestricted = <InverterStatus.OverloadRestricted: 8> Resetting = <InverterStatus.Resetting: 0> Starting = <InverterStatus.Starting: 6> Stopping = <InverterStatus.Stopping: 1> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
class MainProfileParameters(Register)
`` | `MainProfileParameters(value, names=None, *, module=None, qualname=None, type=None, start=1) Main profile parameters group. See datasheet sections 3-4 (p. 89) and B-4 (pp. 319-320, 322-323 and 344).`
| Method resolution order: MainProfileParameters Register enum.Enum builtins.object Data and other attributes defined here: AccelerationTime1 = <MainProfileParameters.AccelerationTime1: (0x1103, 2)> DecelerationTime1 = <MainProfileParameters.DecelerationTime1: (0x1105, 2)> OperatorRotationDirection = <MainProfileParameters.OperatorRotationDirection: (0x1107, 1)> OutputFrequency = <MainProfileParameters.OutputFrequency: (0x01, 2)> SecondAccelerationTime1 = <MainProfileParameters.SecondAccelerationTime1: (0x2103, 2)> SecondDecelerationTime1 = <MainProfileParameters.SecondDecelerationTime1: (0x2105, 2)> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
class ModbusRegisters(Register)
`` | `ModbusRegisters(value, names=None, *, module=None, qualname=None, type=None, start=1) Modbus-only registers. These registers aren't accessible through the keypad interface (datasheet section B-4, pp. 318 and 320).`
| Method resolution order: ModbusRegisters Register enum.Enum builtins.object Data and other attributes defined here: EEPROMWriteMode = <ModbusRegisters.EEPROMWriteMode: (0x902, 1)> InverterStatusA = <ModbusRegisters.InverterStatusA: (0x03, 1)> InverterStatusB = <ModbusRegisters.InverterStatusB: (0x04, 1)> InverterStatusC = <ModbusRegisters.InverterStatusC: (0x05, 1)> PIDFeedback = <ModbusRegisters.PIDFeedback: (0x06, 1)> WriteToEEPROM = <ModbusRegisters.WriteToEEPROM: (0x900, 1)> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
class MonitoringFunctions(Register)
`` | `MonitoringFunctions(value, names=None, *, module=None, qualname=None, type=None, start=1) Intelligent terminal function group. See datasheet sections 3-3 (pp. 74-88) and B-4 (pp. 319-320 and 322-323).`
| Method resolution order: MonitoringFunctions Register enum.Enum builtins.object Data and other attributes defined here: AnalogInputO = <MonitoringFunctions.AnalogInputO: (0x10a1, 1)> AnalogInputOI = <MonitoringFunctions.AnalogInputOI: (0x10a2, 1)> ConvertedOutputFrequency = <MonitoringFunctions.ConvertedOutputFrequency: (0x1009, 2)> CurrentPosition = <MonitoringFunctions.CurrentPosition: (0x1038, 2)> DCVoltage = <MonitoringFunctions.DCVoltage: (0x1026, 1)> DriveProgramming0 = <MonitoringFunctions.DriveProgramming0: (0x102e, 2)> DriveProgramming1 = <MonitoringFunctions.DriveProgramming1: (0x1030, 2)> DriveProgramming2 = <MonitoringFunctions.DriveProgramming2: (0x1032, 2)> ElectronicThermalMonitor = <MonitoringFunctions.ElectronicThermalMonitor: (0x1028, 1)> FaultFrequencyMonitor = <MonitoringFunctions.FaultFrequencyMonitor: (0x11, 1)> FaultMonitor1 = <MonitoringFunctions.FaultMonitor1: (0x12, 1)> FaultMonitor1Current = <MonitoringFunctions.FaultMonitor1Current: (0x16, 1)> FaultMonitor1Frequency = <MonitoringFunctions.FaultMonitor1Frequency: (0x14, 2)> FaultMonitor1InverterStatus = <MonitoringFunctions.FaultMonitor1InverterStatus: (0x13, 1)> FaultMonitor1PowerOnTime = <MonitoringFunctions.FaultMonitor1PowerOnTime: (0x1a, 2)> FaultMonitor1RunningTime = <MonitoringFunctions.FaultMonitor1RunningTime: (0x18, 2)> FaultMonitor1Voltage = <MonitoringFunctions.FaultMonitor1Voltage: (0x17, 1)> FaultMonitor2 = <MonitoringFunctions.FaultMonitor2: (0x1c, 1)> FaultMonitor2Current = <MonitoringFunctions.FaultMonitor2Current: (0x20, 1)> FaultMonitor2Frequency = <MonitoringFunctions.FaultMonitor2Frequency: (0x1e, 2)> FaultMonitor2InverterStatus = <MonitoringFunctions.FaultMonitor2InverterStatus: (0x1d, 1)> FaultMonitor2PowerOnTime = <MonitoringFunctions.FaultMonitor2PowerOnTime: (0x24, 2)> FaultMonitor2RunningTime = <MonitoringFunctions.FaultMonitor2RunningTime: (0x22, 2)> FaultMonitor2Voltage = <MonitoringFunctions.FaultMonitor2Voltage: (0x21, 1)> FaultMonitor3 = <MonitoringFunctions.FaultMonitor3: (0x26, 1)> FaultMonitor3Current = <MonitoringFunctions.FaultMonitor3Current: (0x2a, 1)> FaultMonitor3Frequency = <MonitoringFunctions.FaultMonitor3Frequency: (0x28, 2)> FaultMonitor3InverterStatus = <MonitoringFunctions.FaultMonitor3InverterStatus: (0x27, 1)> FaultMonitor3PowerOnTime = <MonitoringFunctions.FaultMonitor3PowerOnTime: (0x2e, 2)> FaultMonitor3RunningTime = <MonitoringFunctions.FaultMonitor3RunningTime: (0x2c, 2)> FaultMonitor3Voltage = <MonitoringFunctions.FaultMonitor3Voltage: (0x2b, 1)> FaultMonitor4 = <MonitoringFunctions.FaultMonitor4: (0x30, 1)> FaultMonitor4Current = <MonitoringFunctions.FaultMonitor4Current: (0x34, 1)> FaultMonitor4Frequency = <MonitoringFunctions.FaultMonitor4Frequency: (0x32, 2)> FaultMonitor4InverterStatus = <MonitoringFunctions.FaultMonitor4InverterStatus: (0x31, 1)> FaultMonitor4PowerOnTime = <MonitoringFunctions.FaultMonitor4PowerOnTime: (0x38, 2)> FaultMonitor4RunningTime = <MonitoringFunctions.FaultMonitor4RunningTime: (0x36, 2)> FaultMonitor4Voltage = <MonitoringFunctions.FaultMonitor4Voltage: (0x35, 1)> FaultMonitor5 = <MonitoringFunctions.FaultMonitor5: (0x3a, 1)> FaultMonitor5Current = <MonitoringFunctions.FaultMonitor5Current: (0x3e, 1)> FaultMonitor5Frequency = <MonitoringFunctions.FaultMonitor5Frequency: (0x3c, 2)> FaultMonitor5InverterStatus = <MonitoringFunctions.FaultMonitor5InverterStatus: (0x3b, 1)> FaultMonitor5PowerOnTime = <MonitoringFunctions.FaultMonitor5PowerOnTime: (0x42, 2)> FaultMonitor5RunningTime = <MonitoringFunctions.FaultMonitor5RunningTime: (0x40, 2)> FaultMonitor5Voltage = <MonitoringFunctions.FaultMonitor5Voltage: (0x3f, 1)> FaultMonitor6 = <MonitoringFunctions.FaultMonitor6: (0x44, 1)> FaultMonitor6Current = <MonitoringFunctions.FaultMonitor6Current: (0x48, 1)> FaultMonitor6Frequency = <MonitoringFunctions.FaultMonitor6Frequency: (0x46, 2)> FaultMonitor6InverterStatus = <MonitoringFunctions.FaultMonitor6InverterStatus: (0x45, 1)> FaultMonitor6PowerOnTime = <MonitoringFunctions.FaultMonitor6PowerOnTime: (0x4c, 2)> FaultMonitor6RunningTime = <MonitoringFunctions.FaultMonitor6RunningTime: (0x4a, 2)> FaultMonitor6Voltage = <MonitoringFunctions.FaultMonitor6Voltage: (0x49, 1)> FinTemperature = <MonitoringFunctions.FinTemperature: (0x1019, 1)> FrequencySource = <MonitoringFunctions.FrequencySource: (0x1059, 1)> InputPower = <MonitoringFunctions.InputPower: (0x1012, 1)> InverterMode = <MonitoringFunctions.InverterMode: (0x1057, 1)> LifeAssessment = <MonitoringFunctions.LifeAssessment: (0x101d, 1)> MultiFunctionInputs = <MonitoringFunctions.MultiFunctionInputs: (0x1007, 1)> MultiFunctionOutputs = <MonitoringFunctions.MultiFunctionOutputs: (0x1008, 1)> OutputCurrent = <MonitoringFunctions.OutputCurrent: (0x1003, 1)> OutputFrequency = <MonitoringFunctions.OutputFrequency: (0x1001, 2)> OutputTorque = <MonitoringFunctions.OutputTorque: (0x1010, 1)> OutputVoltage = <MonitoringFunctions.OutputVoltage: (0x1011, 1)> PIDDeviation = <MonitoringFunctions.PIDDeviation: (0x10a6, 1)> PIDFeedbackValue = <MonitoringFunctions.PIDFeedbackValue: (0x1005, 2)> PIDOutput = <MonitoringFunctions.PIDOutput: (0x10a8, 1)> PositionCommand = <MonitoringFunctions.PositionCommand: (0x1036, 2)> PowerOnTime = <MonitoringFunctions.PowerOnTime: (0x1017, 2)> ProgramCounter = <MonitoringFunctions.ProgramCounter: (0x101e, 1)> ProgramNumber = <MonitoringFunctions.ProgramNumber: (0x101f, 1)> PulseTrainInput = <MonitoringFunctions.PulseTrainInput: (0x10a4, 1)> RealFrequency = <MonitoringFunctions.RealFrequency: (0x100b, 2)> RegenerativeBrakingLoadRate = <MonitoringFunctions.RegenerativeBrakingLoadRate: (0x1027, 1)> RotationDirection = <MonitoringFunctions.RotationDirection: (0x1004, 1)> RunSource = <MonitoringFunctions.RunSource: (0x105a, 1)> TorqueBias = <MonitoringFunctions.TorqueBias: (0x100e, 1)> TorqueReference = <MonitoringFunctions.TorqueReference: (0x100d, 1)> TotalRunTime = <MonitoringFunctions.TotalRunTime: (0x1015, 2)> WarningMonitor = <MonitoringFunctions.WarningMonitor: (0x4e, 1)> WattHour = <MonitoringFunctions.WattHour: (0x1013, 2)> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
class MotorConstantsFunctions(Register)
`` | `MotorConstantsFunctions(value, names=None, *, module=None, qualname=None, type=None, start=1) Motor constants function group. See datasheet sections 3-8 (pp. 172-178) and B-4 (pp. 337-338).`
| Method resolution order: MotorConstantsFunctions Register enum.Enum builtins.object Data and other attributes defined here: AutoTuningPMParameterLd = <MotorConstantsFunctions.AutoTuningPMParameterLd: (0x157c, 1)> AutoTuningPMParameterLq = <MotorConstantsFunctions.AutoTuningPMParameterLq: (0x157d, 1)> AutoTuningPMParameterR = <MotorConstantsFunctions.AutoTuningPMParameterR: (0x157b, 1)> AutoTuningParameterIo = <MotorConstantsFunctions.AutoTuningParameterIo: (0x152b, 1)> AutoTuningParameterJ = <MotorConstantsFunctions.AutoTuningParameterJ: (0x152c, 2)> AutoTuningParameterR1 = <MotorConstantsFunctions.AutoTuningParameterR1: (0x1525, 1)> AutoTuningParameterR2 = <MotorConstantsFunctions.AutoTuningParameterR2: (0x1527, 1)> AutoTuningSelection = <MotorConstantsFunctions.AutoTuningSelection: (0x1501, 1)> H022 = <MotorConstantsFunctions.H022: (0x151a, 1)> H032 = <MotorConstantsFunctions.H032: (0x1529, 1)> MotorCapacitySelection = <MotorConstantsFunctions.MotorCapacitySelection: (0x1503, 1)> MotorParameterIo = <MotorConstantsFunctions.MotorParameterIo: (0x151c, 1)> MotorParameterJ = <MotorConstantsFunctions.MotorParameterJ: (0x151d, 2)> MotorParameterR1 = <MotorConstantsFunctions.MotorParameterR1: (0x1516, 1)> MotorParameterR2 = <MotorConstantsFunctions.MotorParameterR2: (0x1518, 1)> MotorParameterSelection = <MotorConstantsFunctions.MotorParameterSelection: (0x1502, 1)> MotorPoleNumberSelection = <MotorConstantsFunctions.MotorPoleNumberSelection: (0x1504, 1)> PMIMPE0VWait = <MotorConstantsFunctions.PMIMPE0VWait: (0x158a, 1)> PMIMPEDetect = <MotorConstantsFunctions.PMIMPEDetect: (0x158c, 1)> PMIMPEDetectWait = <MotorConstantsFunctions.PMIMPEDetectWait: (0x158b, 1)> PMIMPEVoltageGain = <MotorConstantsFunctions.PMIMPEVoltageGain: (0x158d, 1)> PMMinimumFrequency = <MotorConstantsFunctions.PMMinimumFrequency: (0x1586, 1)> PMMotorCapacity = <MotorConstantsFunctions.PMMotorCapacity: (0x1572, 1)> PMMotorCodeSelection = <MotorConstantsFunctions.PMMotorCodeSelection: (0x1571, 1)> PMMotorPoleNumberSelection = <MotorConstantsFunctions.PMMotorPoleNumberSelection: (0x1573, 1)> PMNoLoadCurrent = <MotorConstantsFunctions.PMNoLoadCurrent: (0x1587, 1)> PMParameterJ = <MotorConstantsFunctions.PMParameterJ: (0x1579, 2)> PMParameterKe = <MotorConstantsFunctions.PMParameterKe: (0x1578, 1)> PMParameterLd = <MotorConstantsFunctions.PMParameterLd: (0x1576, 1)> PMParameterLq = <MotorConstantsFunctions.PMParameterLq: (0x1577, 1)> PMParameterR = <MotorConstantsFunctions.PMParameterR: (0x1575, 1)> PMRatedCurrent = <MotorConstantsFunctions.PMRatedCurrent: (0x1574, 1)> PMSpeedResponse = <MotorConstantsFunctions.PMSpeedResponse: (0x1581, 1)> PMStabilizationConstant = <MotorConstantsFunctions.PMStabilizationConstant: (0x1584, 1)> PMStartingCurrent = <MotorConstantsFunctions.PMStartingCurrent: (0x1582, 1)> PMStartingMethod = <MotorConstantsFunctions.PMStartingMethod: (0x1588, 1)> PMStartingTime = <MotorConstantsFunctions.PMStartingTime: (0x1583, 1)> SlipCompensationIGain = <MotorConstantsFunctions.SlipCompensationIGain: (0x153e, 1)> SlipCompensationPGain = <MotorConstantsFunctions.SlipCompensationPGain: (0x153d, 1)> SpeedResponse = <MotorConstantsFunctions.SpeedResponse: (0x1506, 1)> StabilizationParameter = <MotorConstantsFunctions.StabilizationParameter: (0x1507, 1)> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
class OtherParameters(Register)
`` | `OtherParameters(value, names=None, *, module=None, qualname=None, type=None, start=1) Other parameters group. See datasheet sections 3-9 (pp. 179-190) and B-4 (pp. 339-343).`
| Method resolution order: OtherParameters Register enum.Enum builtins.object Data and other attributes defined here: AccelerationDecelerationTimeInputType = <OtherParameters.AccelerationDecelerationTimeInputType: (0x161f, 1)> CANOpenCommunicationSpeed = <OtherParameters.CANOpenCommunicationSpeed: (0x16bc, 1)> CANOpenNodeAddress = <OtherParameters.CANOpenNodeAddress: (0x16bb, 1)> CommunicationErrorEffect = <OtherParameters.CommunicationErrorEffect: (0x162f, 1)> CompoNetNodeAddress = <OtherParameters.CompoNetNodeAddress: (0x16c0, 1)> CreepSpeed = <OtherParameters.CreepSpeed: (0x160f, 1)> CurrentPositionAtPowerOff = <OtherParameters.CurrentPositionAtPowerOff: (0x165e, 1)> DeviceNetNodeAddress = <OtherParameters.DeviceNetNodeAddress: (0x16c2, 1)> DriveProgramParameterU00 = <OtherParameters.DriveProgramParameterU00: (0x1666, 1)> DriveProgramParameterU01 = <OtherParameters.DriveProgramParameterU01: (0x1667, 1)> DriveProgramParameterU02 = <OtherParameters.DriveProgramParameterU02: (0x1668, 1)> DriveProgramParameterU03 = <OtherParameters.DriveProgramParameterU03: (0x1669, 1)> DriveProgramParameterU04 = <OtherParameters.DriveProgramParameterU04: (0x166a, 1)> DriveProgramParameterU05 = <OtherParameters.DriveProgramParameterU05: (0x166b, 1)> DriveProgramParameterU06 = <OtherParameters.DriveProgramParameterU06: (0x166c, 1)> DriveProgramParameterU07 = <OtherParameters.DriveProgramParameterU07: (0x166d, 1)> DriveProgramParameterU08 = <OtherParameters.DriveProgramParameterU08: (0x166e, 1)> DriveProgramParameterU09 = <OtherParameters.DriveProgramParameterU09: (0x166f, 1)> DriveProgramParameterU10 = <OtherParameters.DriveProgramParameterU10: (0x1670, 1)> DriveProgramParameterU11 = <OtherParameters.DriveProgramParameterU11: (0x1671, 1)> DriveProgramParameterU12 = <OtherParameters.DriveProgramParameterU12: (0x1672, 1)> DriveProgramParameterU13 = <OtherParameters.DriveProgramParameterU13: (0x1673, 1)> DriveProgramParameterU14 = <OtherParameters.DriveProgramParameterU14: (0x1674, 1)> DriveProgramParameterU15 = <OtherParameters.DriveProgramParameterU15: (0x1675, 1)> DriveProgramParameterU16 = <OtherParameters.DriveProgramParameterU16: (0x1676, 1)> DriveProgramParameterU17 = <OtherParameters.DriveProgramParameterU17: (0x1677, 1)> DriveProgramParameterU18 = <OtherParameters.DriveProgramParameterU18: (0x1678, 1)> DriveProgramParameterU19 = <OtherParameters.DriveProgramParameterU19: (0x1679, 1)> DriveProgramParameterU20 = <OtherParameters.DriveProgramParameterU20: (0x167a, 1)> DriveProgramParameterU21 = <OtherParameters.DriveProgramParameterU21: (0x167b, 1)> DriveProgramParameterU22 = <OtherParameters.DriveProgramParameterU22: (0x167c, 1)> DriveProgramParameterU23 = <OtherParameters.DriveProgramParameterU23: (0x167d, 1)> DriveProgramParameterU24 = <OtherParameters.DriveProgramParameterU24: (0x167e, 1)> DriveProgramParameterU25 = <OtherParameters.DriveProgramParameterU25: (0x167f, 1)> DriveProgramParameterU26 = <OtherParameters.DriveProgramParameterU26: (0x1680, 1)> DriveProgramParameterU27 = <OtherParameters.DriveProgramParameterU27: (0x1681, 1)> DriveProgramParameterU28 = <OtherParameters.DriveProgramParameterU28: (0x1682, 1)> DriveProgramParameterU29 = <OtherParameters.DriveProgramParameterU29: (0x1683, 1)> DriveProgramParameterU30 = <OtherParameters.DriveProgramParameterU30: (0x1684, 1)> DriveProgramParameterU31 = <OtherParameters.DriveProgramParameterU31: (0x1685, 1)> EATerminalFunction = <OtherParameters.EATerminalFunction: (0x1603, 1)> EZCOMMDestination1Address = <OtherParameters.EZCOMMDestination1Address: (0x168f, 1)> EZCOMMDestination1Register = <OtherParameters.EZCOMMDestination1Register: (0x1690, 1)> EZCOMMDestination2Address = <OtherParameters.EZCOMMDestination2Address: (0x1692, 1)> EZCOMMDestination2Register = <OtherParameters.EZCOMMDestination2Register: (0x1693, 1)> EZCOMMDestination3Address = <OtherParameters.EZCOMMDestination3Address: (0x1695, 1)> EZCOMMDestination3Register = <OtherParameters.EZCOMMDestination3Register: (0x1696, 1)> EZCOMMDestination4Address = <OtherParameters.EZCOMMDestination4Address: (0x1698, 1)> EZCOMMDestination4Register = <OtherParameters.EZCOMMDestination4Register: (0x1699, 1)> EZCOMMDestination5Address = <OtherParameters.EZCOMMDestination5Address: (0x169b, 1)> EZCOMMDestination5Register = <OtherParameters.EZCOMMDestination5Register: (0x169c, 1)> EZCOMMSource1Register = <OtherParameters.EZCOMMSource1Register: (0x1691, 1)> EZCOMMSource2Register = <OtherParameters.EZCOMMSource2Register: (0x1694, 1)> EZCOMMSource3Register = <OtherParameters.EZCOMMSource3Register: (0x1697, 1)> EZCOMMSource4Register = <OtherParameters.EZCOMMSource4Register: (0x169a, 1)> EZCOMMSource5Register = <OtherParameters.EZCOMMSource5Register: (0x169d, 1)> EncoderDisconnectionTimeout = <OtherParameters.EncoderDisconnectionTimeout: (0x1659, 1)> EncoderPulses = <OtherParameters.EncoderPulses: (0x160b, 1)> Endianness = <OtherParameters.Endianness: (0x16f1, 1)> EzCOMMDataCount = <OtherParameters.EzCOMMDataCount: (0x168e, 1)> ForwardPositionRangeSpecification = <OtherParameters.ForwardPositionRangeSpecification: (0x1652, 2)> ForwardTorqueControlSpeedLimitValue = <OtherParameters.ForwardTorqueControlSpeedLimitValue: (0x1627, 2)> HighSpeedZeroReturnFrequency = <OtherParameters.HighSpeedZeroReturnFrequency: (0x1651, 1)> InstanceNumber = <OtherParameters.InstanceNumber: (0x1630, 1)> LowSpeedZeroReturnFrequency = <OtherParameters.LowSpeedZeroReturnFrequency: (0x1650, 1)> ModbusExternalRegister1 = <OtherParameters.ModbusExternalRegister1: (0x16c9, 1)> ModbusExternalRegister10 = <OtherParameters.ModbusExternalRegister10: (0x16d2, 1)> ModbusExternalRegister2 = <OtherParameters.ModbusExternalRegister2: (0x16ca, 1)> ModbusExternalRegister3 = <OtherParameters.ModbusExternalRegister3: (0x16cb, 1)> ModbusExternalRegister4 = <OtherParameters.ModbusExternalRegister4: (0x16cc, 1)> ModbusExternalRegister5 = <OtherParameters.ModbusExternalRegister5: (0x16cd, 1)> ModbusExternalRegister6 = <OtherParameters.ModbusExternalRegister6: (0x16ce, 1)> ModbusExternalRegister7 = <OtherParameters.ModbusExternalRegister7: (0x16cf, 1)> ModbusExternalRegister8 = <OtherParameters.ModbusExternalRegister8: (0x16d0, 1)> ModbusExternalRegister9 = <OtherParameters.ModbusExternalRegister9: (0x16d1, 1)> ModbusInternalRegister1 = <OtherParameters.ModbusInternalRegister1: (0x16e7, 1)> ModbusInternalRegister10 = <OtherParameters.ModbusInternalRegister10: (0x16f0, 1)> ModbusInternalRegister2 = <OtherParameters.ModbusInternalRegister2: (0x16e8, 1)> ModbusInternalRegister3 = <OtherParameters.ModbusInternalRegister3: (0x16e9, 1)> ModbusInternalRegister4 = <OtherParameters.ModbusInternalRegister4: (0x16ea, 1)> ModbusInternalRegister5 = <OtherParameters.ModbusInternalRegister5: (0x16eb, 1)> ModbusInternalRegister6 = <OtherParameters.ModbusInternalRegister6: (0x16ec, 1)> ModbusInternalRegister7 = <OtherParameters.ModbusInternalRegister7: (0x16ed, 1)> ModbusInternalRegister8 = <OtherParameters.ModbusInternalRegister8: (0x16ee, 1)> ModbusInternalRegister9 = <OtherParameters.ModbusInternalRegister9: (0x16ef, 1)> ModbusRegisterFormat1 = <OtherParameters.ModbusRegisterFormat1: (0x16d3, 1)> ModbusRegisterFormat10 = <OtherParameters.ModbusRegisterFormat10: (0x16dc, 1)> ModbusRegisterFormat2 = <OtherParameters.ModbusRegisterFormat2: (0x16d4, 1)> ModbusRegisterFormat3 = <OtherParameters.ModbusRegisterFormat3: (0x16d5, 1)> ModbusRegisterFormat4 = <OtherParameters.ModbusRegisterFormat4: (0x16d6, 1)> ModbusRegisterFormat5 = <OtherParameters.ModbusRegisterFormat5: (0x16d7, 1)> ModbusRegisterFormat6 = <OtherParameters.ModbusRegisterFormat6: (0x16d8, 1)> ModbusRegisterFormat7 = <OtherParameters.ModbusRegisterFormat7: (0x16d9, 1)> ModbusRegisterFormat8 = <OtherParameters.ModbusRegisterFormat8: (0x16da, 1)> ModbusRegisterFormat9 = <OtherParameters.ModbusRegisterFormat9: (0x16db, 1)> ModbusRegisterScaling1 = <OtherParameters.ModbusRegisterScaling1: (0x16dd, 1)> ModbusRegisterScaling10 = <OtherParameters.ModbusRegisterScaling10: (0x16e6, 1)> ModbusRegisterScaling2 = <OtherParameters.ModbusRegisterScaling2: (0x16de, 1)> ModbusRegisterScaling3 = <OtherParameters.ModbusRegisterScaling3: (0x16df, 1)> ModbusRegisterScaling4 = <OtherParameters.ModbusRegisterScaling4: (0x16e0, 1)> ModbusRegisterScaling5 = <OtherParameters.ModbusRegisterScaling5: (0x16e1, 1)> ModbusRegisterScaling6 = <OtherParameters.ModbusRegisterScaling6: (0x16e2, 1)> ModbusRegisterScaling7 = <OtherParameters.ModbusRegisterScaling7: (0x16e3, 1)> ModbusRegisterScaling8 = <OtherParameters.ModbusRegisterScaling8: (0x16e4, 1)> ModbusRegisterScaling9 = <OtherParameters.ModbusRegisterScaling9: (0x16e5, 1)> MultiStepPositionCommand0 = <OtherParameters.MultiStepPositionCommand0: (0x163e, 2)> MultiStepPositionCommand1 = <OtherParameters.MultiStepPositionCommand1: (0x1640, 2)> MultiStepPositionCommand2 = <OtherParameters.MultiStepPositionCommand2: (0x1642, 2)> MultiStepPositionCommand3 = <OtherParameters.MultiStepPositionCommand3: (0x1644, 2)> MultiStepPositionCommand4 = <OtherParameters.MultiStepPositionCommand4: (0x1646, 2)> MultiStepPositionCommand5 = <OtherParameters.MultiStepPositionCommand5: (0x1648, 2)> MultiStepPositionCommand6 = <OtherParameters.MultiStepPositionCommand6: (0x164a, 2)> MultiStepPositionCommand7 = <OtherParameters.MultiStepPositionCommand7: (0x164c, 2)> NetworkCommunicationWatchdogTimer = <OtherParameters.NetworkCommunicationWatchdogTimer: (0x162e, 1)> OperationSelectionAtOption1Error = <OtherParameters.OperationSelectionAtOption1Error: (0x1601, 1)> OperationSettingInIdleMode = <OtherParameters.OperationSettingInIdleMode: (0x1632, 1)> OptionIFCommandReadRegister1 = <OtherParameters.OptionIFCommandReadRegister1: (0x16ac, 1)> OptionIFCommandReadRegister10 = <OtherParameters.OptionIFCommandReadRegister10: (0x16b5, 1)> OptionIFCommandReadRegister2 = <OtherParameters.OptionIFCommandReadRegister2: (0x16ad, 1)> OptionIFCommandReadRegister3 = <OtherParameters.OptionIFCommandReadRegister3: (0x16ae, 1)> OptionIFCommandReadRegister4 = <OtherParameters.OptionIFCommandReadRegister4: (0x16af, 1)> OptionIFCommandReadRegister5 = <OtherParameters.OptionIFCommandReadRegister5: (0x16b0, 1)> OptionIFCommandReadRegister6 = <OtherParameters.OptionIFCommandReadRegister6: (0x16b1, 1)> OptionIFCommandReadRegister7 = <OtherParameters.OptionIFCommandReadRegister7: (0x16b2, 1)> OptionIFCommandReadRegister8 = <OtherParameters.OptionIFCommandReadRegister8: (0x16b3, 1)> OptionIFCommandReadRegister9 = <OtherParameters.OptionIFCommandReadRegister9: (0x16b4, 1)> OptionIFCommandWriteRegister1 = <OtherParameters.OptionIFCommandWriteRegister1: (0x16a2, 1)> OptionIFCommandWriteRegister10 = <OtherParameters.OptionIFCommandWriteRegister10: (0x16ab, 1)> OptionIFCommandWriteRegister2 = <OtherParameters.OptionIFCommandWriteRegister2: (0x16a3, 1)> OptionIFCommandWriteRegister3 = <OtherParameters.OptionIFCommandWriteRegister3: (0x16a4, 1)> OptionIFCommandWriteRegister4 = <OtherParameters.OptionIFCommandWriteRegister4: (0x16a5, 1)> OptionIFCommandWriteRegister5 = <OtherParameters.OptionIFCommandWriteRegister5: (0x16a6, 1)> OptionIFCommandWriteRegister6 = <OtherParameters.OptionIFCommandWriteRegister6: (0x16a7, 1)> OptionIFCommandWriteRegister7 = <OtherParameters.OptionIFCommandWriteRegister7: (0x16a8, 1)> OptionIFCommandWriteRegister8 = <OtherParameters.OptionIFCommandWriteRegister8: (0x16a9, 1)> OptionIFCommandWriteRegister9 = <OtherParameters.OptionIFCommandWriteRegister9: (0x16aa, 1)> OverSpeedErrorDetectionLevel = <OtherParameters.OverSpeedErrorDetectionLevel: (0x161a, 1)> PolaritySettingForRotationSpeed = <OtherParameters.PolaritySettingForRotationSpeed: (0x1633, 1)> PositionRestartRange = <OtherParameters.PositionRestartRange: (0x165c, 1)> PositioningMode = <OtherParameters.PositioningMode: (0x1657, 1)> PositioningRange = <OtherParameters.PositioningRange: (0x1611, 1)> PresetPosition = <OtherParameters.PresetPosition: (0x1660, 1)> ProfibusClearMode = <OtherParameters.ProfibusClearMode: (0x16b7, 1)> ProfibusMapSelection = <OtherParameters.ProfibusMapSelection: (0x16b8, 1)> ProfibusNodeAddress = <OtherParameters.ProfibusNodeAddress: (0x16b6, 1)> PulseInputLowerCut = <OtherParameters.PulseInputLowerCut: (0x163d, 1)> PulseTrainFrequencyBiasAmount = <OtherParameters.PulseTrainFrequencyBiasAmount: (0x163b, 1)> PulseTrainFrequencyFilterTimeConstant = <OtherParameters.PulseTrainFrequencyFilterTimeConstant: (0x163a, 1)> PulseTrainFrequencyLimit = <OtherParameters.PulseTrainFrequencyLimit: (0x163c, 1)> PulseTrainFrequencyScale = <OtherParameters.PulseTrainFrequencyScale: (0x1639, 1)> PulseTrainInputModeForFeedback = <OtherParameters.PulseTrainInputModeForFeedback: (0x1604, 1)> ReversePositionRangeSpecification = <OtherParameters.ReversePositionRangeSpecification: (0x1654, 2)> ReverseTorqueControlSpeedLimitValue = <OtherParameters.ReverseTorqueControlSpeedLimitValue: (0x1629, 2)> SavePositionAtPowerOff = <OtherParameters.SavePositionAtPowerOff: (0x165d, 1)> SerialCommunicationMode = <OtherParameters.SerialCommunicationMode: (0x16c8, 1)> SimplePositioning = <OtherParameters.SimplePositioning: (0x160c, 1)> SpeedDeviationErrorDetectionLevel = <OtherParameters.SpeedDeviationErrorDetectionLevel: (0x161b, 1)> SpeedTorqueControlSwitchingTime = <OtherParameters.SpeedTorqueControlSwitchingTime: (0x162b, 1)> TorqueBiasMode = <OtherParameters.TorqueBiasMode: (0x1624, 1)> TorqueBiasPolaritySelection = <OtherParameters.TorqueBiasPolaritySelection: (0x1626, 1)> TorqueBiasValue = <OtherParameters.TorqueBiasValue: (0x1625, 1)> TorqueReferenceInputSelection = <OtherParameters.TorqueReferenceInputSelection: (0x1621, 1)> TorqueReferenceSetting = <OtherParameters.TorqueReferenceSetting: (0x1622, 1)> ZeroReturnDirection = <OtherParameters.ZeroReturnDirection: (0x164f, 1)> ZeroReturnMode = <OtherParameters.ZeroReturnMode: (0x164e, 1)> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
class Register(enum.Enum)
`` | `Register(value, names=None, *, module=None, qualname=None, type=None, start=1) Base enum class for register address.`
| Method resolution order: Register enum.Enum builtins.object Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
class SecondMotorFunctions(Register)
`` | `SecondMotorFunctions(value, names=None, *, module=None, qualname=None, type=None, start=1) Second motor function group. See datasheet sections 3-x and B-4 (pp. 344-346).`
| Method resolution order: SecondMotorFunctions Register enum.Enum builtins.object Data and other attributes defined here: AVRSelection = <SecondMotorFunctions.AVRSelection: (0x2269, 1)> AVRVoltageSelection = <SecondMotorFunctions.AVRVoltageSelection: (0x226a, 1)> Acc1ToAcc2FrequencyTransitionPoint = <SecondMotorFunctions.Acc1ToAcc2FrequencyTransitionPoint: (0x2279, 2)> AccelerationTime2 = <SecondMotorFunctions.AccelerationTime2: (0x2274, 2)> AutoTuningParameterIo = <SecondMotorFunctions.AutoTuningParameterIo: (0x252b, 1)> AutoTuningParameterJ = <SecondMotorFunctions.AutoTuningParameterJ: (0x252c, 2)> AutoTuningParameterR1 = <SecondMotorFunctions.AutoTuningParameterR1: (0x2525, 1)> AutoTuningParameterR2 = <SecondMotorFunctions.AutoTuningParameterR2: (0x2527, 1)> AutomaticTorqueBoostSlipCompensationGain = <SecondMotorFunctions.AutomaticTorqueBoostSlipCompensationGain: (0x2241, 1)> AutomaticTorqueBoostVoltageCompensationGain = <SecondMotorFunctions.AutomaticTorqueBoostVoltageCompensationGain: (0x2240, 1)> BaseFrequency = <SecondMotorFunctions.BaseFrequency: (0x2203, 1)> Dec1ToDec2FrequencyTransitionPoint = <SecondMotorFunctions.Dec1ToDec2FrequencyTransitionPoint: (0x227b, 2)> DecelerationTime2 = <SecondMotorFunctions.DecelerationTime2: (0x2276, 2)> ElectronicThermalCharacteristicsSelection = <SecondMotorFunctions.ElectronicThermalCharacteristicsSelection: (0x230d, 1)> ElectronicThermalLevel = <SecondMotorFunctions.ElectronicThermalLevel: (0x230c, 1)> FrequencyLowerLimit = <SecondMotorFunctions.FrequencyLowerLimit: (0x2251, 2)> FrequencyReferenceSelection = <SecondMotorFunctions.FrequencyReferenceSelection: (0x2201, 1)> FrequencyUpperLimit = <SecondMotorFunctions.FrequencyUpperLimit: (0x224f, 2)> H222 = <SecondMotorFunctions.H222: (0x251a, 1)> H232 = <SecondMotorFunctions.H232: (0x2529, 1)> ManualTorqueBoostFrequency = <SecondMotorFunctions.ManualTorqueBoostFrequency: (0x223d, 1)> ManualTorqueBoostVoltage = <SecondMotorFunctions.ManualTorqueBoostVoltage: (0x223c, 1)> MaximumFrequency = <SecondMotorFunctions.MaximumFrequency: (0x2204, 1)> MethodToSwitchToAcc2Dec2 = <SecondMotorFunctions.MethodToSwitchToAcc2Dec2: (0x2278, 1)> MotorCapacitySelection = <SecondMotorFunctions.MotorCapacitySelection: (0x2503, 1)> MotorParameterIo = <SecondMotorFunctions.MotorParameterIo: (0x251c, 1)> MotorParameterJ = <SecondMotorFunctions.MotorParameterJ: (0x251d, 2)> MotorParameterR1 = <SecondMotorFunctions.MotorParameterR1: (0x2516, 1)> MotorParameterR2 = <SecondMotorFunctions.MotorParameterR2: (0x2518, 1)> MotorParameterSelection = <SecondMotorFunctions.MotorParameterSelection: (0x2502, 1)> MotorPoleNumberSelection = <SecondMotorFunctions.MotorPoleNumberSelection: (0x2504, 1)> MultiStepSpeedReference0 = <SecondMotorFunctions.MultiStepSpeedReference0: (0x2216, 2)> OutputVoltageGain = <SecondMotorFunctions.OutputVoltageGain: (0x223f, 1)> OverloadLimitLevel = <SecondMotorFunctions.OverloadLimitLevel: (0x2317, 1)> OverloadLimitParameter = <SecondMotorFunctions.OverloadLimitParameter: (0x2318, 1)> OverloadLimitSelection = <SecondMotorFunctions.OverloadLimitSelection: (0x2316, 1)> OverloadWarningLevel = <SecondMotorFunctions.OverloadWarningLevel: (0x2429, 1)> RunCommandSelection = <SecondMotorFunctions.RunCommandSelection: (0x2202, 1)> SpeedResponse = <SecondMotorFunctions.SpeedResponse: (0x2506, 1)> TorqueBoostSelection = <SecondMotorFunctions.TorqueBoostSelection: (0x223b, 1)> VFCharacteristicsSelection = <SecondMotorFunctions.VFCharacteristicsSelection: (0x223e, 1)> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
class StandardFunctions(Register)
`` | `StandardFunctions(value, names=None, *, module=None, qualname=None, type=None, start=1) Standard function group. See datasheet sections 3-5 (pp. 90-120) and B-4 (pp. 324-327).`
| Method resolution order: StandardFunctions Register enum.Enum builtins.object Data and other attributes defined here: AVRDecelerationGain = <StandardFunctions.AVRDecelerationGain: (0x126c, 1)> AVRFilterTimeConstant = <StandardFunctions.AVRFilterTimeConstant: (0x126b, 1)> AVRSelection = <StandardFunctions.AVRSelection: (0x1269, 1)> AVRVoltageSelection = <StandardFunctions.AVRVoltageSelection: (0x126a, 1)> Acc1ToAcc2FrequencyTransitionPoint = <StandardFunctions.Acc1ToAcc2FrequencyTransitionPoint: (0x1279, 2)> AccelerationCurveParameter = <StandardFunctions.AccelerationCurveParameter: (0x12a5, 1)> AccelerationCurveSelection = <StandardFunctions.AccelerationCurveSelection: (0x127d, 1)> AccelerationStopFrequency = <StandardFunctions.AccelerationStopFrequency: (0x125c, 2)> AccelerationStopTime = <StandardFunctions.AccelerationStopTime: (0x125e, 1)> AccelerationTime2 = <StandardFunctions.AccelerationTime2: (0x1274, 2)> AutomaticTorqueBoostSlipCompensationGain = <StandardFunctions.AutomaticTorqueBoostSlipCompensationGain: (0x1241, 1)> AutomaticTorqueBoostVoltageCompensationGain = <StandardFunctions.AutomaticTorqueBoostVoltageCompensationGain: (0x1240, 1)> BaseFrequency = <StandardFunctions.BaseFrequency: (0x1203, 1)> CurrentInputActiveRangeEndFrequency = <StandardFunctions.CurrentInputActiveRangeEndFrequency: (0x1283, 2)> CurrentInputActiveRangeEndRatio = <StandardFunctions.CurrentInputActiveRangeEndRatio: (0x1286, 1)> CurrentInputActiveRangeStartFrequency = <StandardFunctions.CurrentInputActiveRangeStartFrequency: (0x1281, 2)> CurrentInputActiveRangeStartRatio = <StandardFunctions.CurrentInputActiveRangeStartRatio: (0x1285, 1)> CurrentInputStartFrequencyEnable = <StandardFunctions.CurrentInputStartFrequencyEnable: (0x1287, 1)> DCInjectionBrakingCarrierFrequency = <StandardFunctions.DCInjectionBrakingCarrierFrequency: (0x124d, 1)> DCInjectionBrakingDelayTime = <StandardFunctions.DCInjectionBrakingDelayTime: (0x1247, 1)> DCInjectionBrakingEnable = <StandardFunctions.DCInjectionBrakingEnable: (0x1245, 1)> DCInjectionBrakingFrequency = <StandardFunctions.DCInjectionBrakingFrequency: (0x1246, 1)> DCInjectionBrakingMethodSelection = <StandardFunctions.DCInjectionBrakingMethodSelection: (0x124a, 1)> DCInjectionBrakingPower = <StandardFunctions.DCInjectionBrakingPower: (0x1248, 1)> DCInjectionBrakingTime = <StandardFunctions.DCInjectionBrakingTime: (0x1249, 1)> Dec1ToDec2FrequencyTransitionPoint = <StandardFunctions.Dec1ToDec2FrequencyTransitionPoint: (0x127b, 2)> DecelerationCurveParameter = <StandardFunctions.DecelerationCurveParameter: (0x12a6, 1)> DecelerationCurveSelection = <StandardFunctions.DecelerationCurveSelection: (0x127e, 1)> DecelerationHoldFrequency = <StandardFunctions.DecelerationHoldFrequency: (0x12bd, 2)> DecelerationHoldTime = <StandardFunctions.DecelerationHoldTime: (0x12bf, 1)> DecelerationTime2 = <StandardFunctions.DecelerationTime2: (0x1276, 2)> DriveProgramming = <StandardFunctions.DriveProgramming: (0x1213, 1)> ELSCurveRatio1DuringAcceleration = <StandardFunctions.ELSCurveRatio1DuringAcceleration: (0x12b9, 1)> ELSCurveRatio1DuringDeceleration = <StandardFunctions.ELSCurveRatio1DuringDeceleration: (0x12bb, 1)> ELSCurveRatio2DuringAcceleration = <StandardFunctions.ELSCurveRatio2DuringAcceleration: (0x12ba, 1)> ELSCurveRatio2DuringDeceleration = <StandardFunctions.ELSCurveRatio2DuringDeceleration: (0x12bc, 1)> EnergySavingOperationMode = <StandardFunctions.EnergySavingOperationMode: (0x126d, 1)> EnergySavingResponseAccuracyAdjustment = <StandardFunctions.EnergySavingResponseAccuracyAdjustment: (0x126e, 1)> ExternalFrequencyFilterTimeConstant = <StandardFunctions.ExternalFrequencyFilterTimeConstant: (0x1212, 1)> FrequencyAdditionAmount = <StandardFunctions.FrequencyAdditionAmount: (0x12b3, 2)> FrequencyAdditionDirection = <StandardFunctions.FrequencyAdditionDirection: (0x12b5, 1)> FrequencyLowerLimit = <StandardFunctions.FrequencyLowerLimit: (0x1251, 2)> FrequencyReferenceSelection = <StandardFunctions.FrequencyReferenceSelection: (0x1201, 1)> FrequencyUpperLimit = <StandardFunctions.FrequencyUpperLimit: (0x124f, 2)> IOVoltageCurrentSelection = <StandardFunctions.IOVoltageCurrentSelection: (0x1205, 1)> JoggingFrequency = <StandardFunctions.JoggingFrequency: (0x1238, 1)> JoggingStopSelection = <StandardFunctions.JoggingStopSelection: (0x1239, 1)> JumpFrequency1 = <StandardFunctions.JumpFrequency1: (0x1253, 2)> JumpFrequency2 = <StandardFunctions.JumpFrequency2: (0x1256, 2)> JumpFrequency3 = <StandardFunctions.JumpFrequency3: (0x1259, 2)> JumpFrequencyWidth1 = <StandardFunctions.JumpFrequencyWidth1: (0x1255, 1)> JumpFrequencyWidth2 = <StandardFunctions.JumpFrequencyWidth2: (0x1258, 1)> JumpFrequencyWidth3 = <StandardFunctions.JumpFrequencyWidth3: (0x125b, 1)> ManualTorqueBoostFrequency = <StandardFunctions.ManualTorqueBoostFrequency: (0x123d, 1)> ManualTorqueBoostVoltage = <StandardFunctions.ManualTorqueBoostVoltage: (0x123c, 1)> MaximumFrequency = <StandardFunctions.MaximumFrequency: (0x1204, 1)> MethodToSwitchToAcc2Dec2 = <StandardFunctions.MethodToSwitchToAcc2Dec2: (0x1278, 1)> MultiStepSpeedReference0 = <StandardFunctions.MultiStepSpeedReference0: (0x1216, 2)> MultiStepSpeedReference1 = <StandardFunctions.MultiStepSpeedReference1: (0x1218, 2)> MultiStepSpeedReference10 = <StandardFunctions.MultiStepSpeedReference10: (0x122a, 2)> MultiStepSpeedReference11 = <StandardFunctions.MultiStepSpeedReference11: (0x122c, 2)> MultiStepSpeedReference12 = <StandardFunctions.MultiStepSpeedReference12: (0x122e, 2)> MultiStepSpeedReference13 = <StandardFunctions.MultiStepSpeedReference13: (0x1230, 2)> MultiStepSpeedReference14 = <StandardFunctions.MultiStepSpeedReference14: (0x1232, 2)> MultiStepSpeedReference15 = <StandardFunctions.MultiStepSpeedReference15: (0x1234, 2)> MultiStepSpeedReference2 = <StandardFunctions.MultiStepSpeedReference2: (0x121a, 2)> MultiStepSpeedReference3 = <StandardFunctions.MultiStepSpeedReference3: (0x121c, 2)> MultiStepSpeedReference4 = <StandardFunctions.MultiStepSpeedReference4: (0x121e, 2)> MultiStepSpeedReference5 = <StandardFunctions.MultiStepSpeedReference5: (0x1220, 2)> MultiStepSpeedReference6 = <StandardFunctions.MultiStepSpeedReference6: (0x1222, 2)> MultiStepSpeedReference7 = <StandardFunctions.MultiStepSpeedReference7: (0x1224, 2)> MultiStepSpeedReference8 = <StandardFunctions.MultiStepSpeedReference8: (0x1226, 2)> MultiStepSpeedReference9 = <StandardFunctions.MultiStepSpeedReference9: (0x1228, 2)> MultiStepSpeedSelection = <StandardFunctions.MultiStepSpeedSelection: (0x1215, 1)> OperationFrequencyInputASelection = <StandardFunctions.OperationFrequencyInputASelection: (0x12af, 1)> OperationFrequencyInputBSelection = <StandardFunctions.OperationFrequencyInputBSelection: (0x12b0, 1)> OperationSelection = <StandardFunctions.OperationSelection: (0x12b1, 1)> OutputVoltageGain = <StandardFunctions.OutputVoltageGain: (0x123f, 1)> PIDDGain = <StandardFunctions.PIDDGain: (0x1262, 1)> PIDFeedForwardSelection = <StandardFunctions.PIDFeedForwardSelection: (0x1267, 1)> PIDFeedbackSelection = <StandardFunctions.PIDFeedbackSelection: (0x1264, 1)> PIDIGain = <StandardFunctions.PIDIGain: (0x1261, 1)> PIDOutputLimitFunction = <StandardFunctions.PIDOutputLimitFunction: (0x1266, 1)> PIDPGain = <StandardFunctions.PIDPGain: (0x1260, 1)> PIDScale = <StandardFunctions.PIDScale: (0x1263, 1)> PIDSelection = <StandardFunctions.PIDSelection: (0x125f, 1)> PIDSleepFunctionActionDelayTime = <StandardFunctions.PIDSleepFunctionActionDelayTime: (0x12c2, 1)> PIDSleepFunctionActionThreshold = <StandardFunctions.PIDSleepFunctionActionThreshold: (0x12c0, 2)> ReversePIDFunction = <StandardFunctions.ReversePIDFunction: (0x1265, 1)> RunCommandSelection = <StandardFunctions.RunCommandSelection: (0x1202, 1)> StartupDCInjectionBrakingPower = <StandardFunctions.StartupDCInjectionBrakingPower: (0x124b, 1)> StartupDCInjectionBrakingTime = <StandardFunctions.StartupDCInjectionBrakingTime: (0x124c, 1)> TorqueBoostSelection = <StandardFunctions.TorqueBoostSelection: (0x123b, 1)> VFCharacteristicsSelection = <StandardFunctions.VFCharacteristicsSelection: (0x123e, 1)> VRInputActiveRangeEndFrequency = <StandardFunctions.VRInputActiveRangeEndFrequency: (0x12c8, 2)> VRInputActiveRangeEndVoltage = <StandardFunctions.VRInputActiveRangeEndVoltage: (0x12cb, 1)> VRInputActiveRangeStartCurrent = <StandardFunctions.VRInputActiveRangeStartCurrent: (0x12ca, 1)> VRInputActiveRangeStartFrequency = <StandardFunctions.VRInputActiveRangeStartFrequency: (0x12c6, 2)> VRInputStartFrequencyEnable = <StandardFunctions.VRInputStartFrequencyEnable: (0x12cc, 1)> VoltageEndFrequency = <StandardFunctions.VoltageEndFrequency: (0x120d, 2)> VoltageEndRatio = <StandardFunctions.VoltageEndRatio: (0x1210, 1)> VoltageStartFrequency = <StandardFunctions.VoltageStartFrequency: (0x120b, 2)> VoltageStartRatio = <StandardFunctions.VoltageStartRatio: (0x120f, 1)> VoltageStartSelection = <StandardFunctions.VoltageStartSelection: (0x1211, 1)> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
class TripFactor(enum.IntEnum)
`` | `TripFactor(value, names=None, *, module=None, qualname=None, type=None, start=1) Codes identifying the reason of a trip event (datasheet section B-4 p. 421).`
| Method resolution order: TripFactor enum.IntEnum builtins.int enum.Enum builtins.object Data and other attributes defined here: BrakingError = <TripFactor.BrakingError: 36> BrakingResistorOverloadProtection = <TripFactor.BrakingResistorOverloadProtection: 6> CPUError = <TripFactor.CPUError: 11> CPUErrorAlt = <TripFactor.CPUErrorAlt: 22> CurrentDetectionError = <TripFactor.CurrentDetectionError: 10> DriverError = <TripFactor.DriverError: 30> EEPROMError = <TripFactor.EEPROMError: 8> EasySequenceExecutionError = <TripFactor.EasySequenceExecutionError: 45> EasySequenceUserTrip0 = <TripFactor.EasySequenceUserTrip0: 50> EasySequenceUserTrip1 = <TripFactor.EasySequenceUserTrip1: 51> EasySequenceUserTrip2 = <TripFactor.EasySequenceUserTrip2: 52> EasySequenceUserTrip3 = <TripFactor.EasySequenceUserTrip3: 53> EasySequenceUserTrip4 = <TripFactor.EasySequenceUserTrip4: 54> EasySequenceUserTrip5 = <TripFactor.EasySequenceUserTrip5: 55> EasySequenceUserTrip6 = <TripFactor.EasySequenceUserTrip6: 56> EasySequenceUserTrip7 = <TripFactor.EasySequenceUserTrip7: 57> EasySequenceUserTrip8 = <TripFactor.EasySequenceUserTrip8: 58> EasySequenceUserTrip9 = <TripFactor.EasySequenceUserTrip9: 59> EncoderDisconnection = <TripFactor.EncoderDisconnection: 80> ExcessiveSpeed = <TripFactor.ExcessiveSpeed: 81> ExternalTrip = <TripFactor.ExternalTrip: 12> GroundFaultProtection = <TripFactor.GroundFaultProtection: 14> InputOvervoltageProtection = <TripFactor.InputOvervoltageProtection: 15> InvalidInstruction = <TripFactor.InvalidInstruction: 43> InvalidNestingCount = <TripFactor.InvalidNestingCount: 44> InverterThermalTrip = <TripFactor.InverterThermalTrip: 21> LowSpeedOverloadProtection = <TripFactor.LowSpeedOverloadProtection: 38> MainCircuitError = <TripFactor.MainCircuitError: 25> ModbusCommunicationError = <TripFactor.ModbusCommunicationError: 41> NoFactor = <TripFactor.NoFactor: 0> OperatorConnection = <TripFactor.OperatorConnection: 40> OptionError0 = <TripFactor.OptionError0: 60> OptionError1 = <TripFactor.OptionError1: 61> OptionError2 = <TripFactor.OptionError2: 62> OptionError3 = <TripFactor.OptionError3: 63> OptionError4 = <TripFactor.OptionError4: 64> OptionError5 = <TripFactor.OptionError5: 65> OptionError6 = <TripFactor.OptionError6: 66> OptionError7 = <TripFactor.OptionError7: 67> OptionError8 = <TripFactor.OptionError8: 68> OptionError9 = <TripFactor.OptionError9: 69> OverCurrentAtConstantSpeed = <TripFactor.OverCurrentAtConstantSpeed: 1> OverCurrentDuringAcceleration = <TripFactor.OverCurrentDuringAcceleration: 3> OverCurrentDuringDeceleration = <TripFactor.OverCurrentDuringDeceleration: 2> OverCurrentInOtherCondition = <TripFactor.OverCurrentInOtherCondition: 4> OverloadProtection = <TripFactor.OverloadProtection: 5> OvervoltageProtection = <TripFactor.OvervoltageProtection: 7> PositionControlRangeTrip = <TripFactor.PositionControlRangeTrip: 83> SafeStop = <TripFactor.SafeStop: 37> ThermistorError = <TripFactor.ThermistorError: 35> USPError = <TripFactor.USPError: 13> UndervoltageProtection = <TripFactor.UndervoltageProtection: 9> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`

Data
`` |  | __all__ = ['FunctionCode', 'ExceptionCode', 'Coil', 'Register', 'ModbusRegisters', 'StandardFunctions', 'FineTuningFunctions', 'IntelligentTerminalFunctions', 'MonitoringFunctions', 'MainProfileParameters', 'MotorConstantsFunctions', 'OtherParameters', 'SecondMotorFunctions', 'FaultMonitorData', 'TripFactor', 'InverterStatus', 'GroupA', 'GroupB', 'GroupC', 'GroupD', ...]